clear
set more off

cd /path/data  /*specify path for data*/
global OUTPUT /path/output /*specify path for output*/

global dir_logfiles $OUTPUT/log_round3
global dir_tables   $OUTPUT/tables_round3
global dir_figures  $OUTPUT/figures_round3

global fpost /users/$USER 

cap log close

graph set window fontface Helvetica

global logname CHECKING_ACCOUNTS_REG_DIETZ
log using $dir_logfiles/$logname.log, replace
di "$S_DATE"


**************************** PROGRAMS *****************************************************************
cap program drop rank
	program define rank
	args vartorank byvar howmanyp
	cap drop rrr nnn
	egen rrr=rank(`vartorank'),by(`byvar') unique
	egen nnn=count(`vartorank'),by(`byvar') 
	cap drop q`howmanyp'_`vartorank'
	gen q`howmanyp'_`vartorank'=ceil((rrr/nnn)*`howmanyp')
	drop rrr nnn
end

cap program drop trim
	program define trim
	args vartotrim ltrim htrim
		foreach vvv in `vartotrim' {
			qui:{
				cap drop aux*
				gen aux=`vvv'
				forvalues yyy=2005(1)2016{
					_pctile aux if year==`yyy', p(`ltrim' `htrim')
					replace aux=. if year==`yyy' & inrange(aux,r(r1), r(r2))==0 
				}
				cap drop trimmed_`vvv'
				gen trimmed_`vvv'=aux
			}
			disp "trim `vvv' done"
		}
end
***************************************************************************************************

*****EXTRA DATASETS FOR USE IN DEPOSIT ACCOUNT DATASET****************************************************
u lnr male using "/path/data/pre_reg_v1_September_2019_100pct.dta",clear
gcollapse male,by(lnr) 
sort lnr
save temp_gender,replace

u lnr year q100Lnw_TAX using "/path/data/pre_reg_v1_September_2019_100pct.dta",clear
sort lnr year
save temp_position_wealth,replace
**********************************************************************************************************

u bank_account_merged100pct, clear
sort lnr
drop _merge
merge lnr using temp_gender
drop if _merge==2
drop _merge

sort lnr year
merge lnr year using temp_position_wealth
tab _merge
drop if _merge==2
drop _merge

bys lnr year: gen nobs=_n
egen nyears=sum(nobs==1),by(lnr)
keep if nyears==12		/*Keep balanced panel*/

ren bankID bankIDold
ren lastyearbankID bankID

drop if deposits 		<=0		/*Drop debt accounts*/
drop if interes_rec 	< 0		/*The rest of the selection drops only a handful of erroneous records of various type*/
drop if interest_paid 	< 0
drop if debt			< 0
drop if debt			> 0

drop if deposits<500			/*To avoid "christmas bias" */
drop if deposits>260000			/*No deposit insurance above this*/

sort lnr account year
qby lnr account: g dy=year-year[_n-1]

*DIETZ
g num_ret=interes_rec
qby lnr account: gen den_ret=0.5*(deposit+deposit[_n-1]) - 0.5*interes_rec		/*Dietz adjustment*/
qby lnr account: replace den_ret=0 if (deposit+deposit[_n-1])==0
g accint=num_ret/den_ret
replace accint=. if dy>1						/*Use only consecutive-year observations*/
replace accint=0 if accint<0

gegen numb_acc=sum(lnr!=.),by(lnr year)			/*number of accounts per year*/
gegen nyw_acc =sum(lnr!=.),by(lnr account)		/*number of years with account*/
gegen naw_bank=sum(lnr!=.),by(lnr year bankID)	/*number of accounts with the same bank*/


g raccint=accint-inflation
trim raccint 0.01 99.5							/*Trim at top 0.5% (the trim at bottom 0.01% is not operative - it's zero)*/ 
gen return=trimmed_raccint*100

drop if raccint == .	

gen logD=log(deposits)
g age2=age^2
replace educ_year=10 if educ_year<10

set matsize 5000

eststo clear
eststo: areg return age age2 male econ_busD educ_year missing_educ numb_acc nyw_acc naw_bank logD i.year, abs(bankID) cluster(lnr)
eststo: areg return age age2 male econ_busD educ_year missing_educ numb_acc nyw_acc naw_bank logD i.year i.bankID,abs(lnr) cluster(lnr)
predict indFE, d
testparm i.bankID
qui parmest, format(estimate) list(,) saving(temp_FE_bank.dta, replace)

esttab using "$dir_tables/TABLE_10.tex",nostar se(4) b(4) nogaps ar2 replace ///
	keep(age age2 male econ_busD educ_year numb_acc naw_bank nyw_acc logD)
! $fpost/fpost "$dir_tables/TABLE_10.tex"

***EXTRACTS BANK FE
preserve
	u temp_FE_bank, replace
	keep parm estimate
	gen bank = substr(parm, -7,7)
	keep if bank == ".bankID"
	gen bankID = substr(parm,1,10)
	gen byte notnumeric = real(bankID) == .
	drop if notnum == 1
	drop notnum
	destring bankID, replace
	format bankID %15.0g
	bysort bankID: keep if _n == 1
	keep bankID estimate
	ren estimate BankFE
	sort bankID
	save bank_FE_dataset, replace
restore

sort bankID
cap drop _merge
merge bankID using bank_FE_dataset
drop _merge

/*normalize fixed effects at 0*/
sort bankID
qui su BankFE
replace BankFE=BankFE-r(mean)		/*Could normalize inside bank_FE_dataset, but it'd be a mere axis translation*/
sort lnr
su indFE if lnr!=lnr[_n-1],d
replace indFE=indFE-r(mean)


preserve
	gcollapse BankFE ,by(educ_year)
	binscatter BankFE educ_year, saving(bankFE_checking,replace) xtitle(Years of schooling) graphr(c(white)) ytitle("Average Bank FE") 
restore

preserve
	gegen match_ib=group(lnr bankID)
	gcollapse BankFE indFE,by(match_ib)
	egen rankiFE=rank(indFE),unique
	egen nrankiFE=count(indFE)
	gen q100_rankiFE=ceil((rankiFE/nrankiFE)*100)
	binscatter BankFE q100_rankiFE, n(100) saving(indFE_checking,replace) xtitle("Percentile of indiv. FE distrib.") graphr(c(white)) ytitle("Average Bank FE") line(none)
	graph combine bankFE_checking.gph indFE_checking.gph,graphr(c(white))
	graph export "$dir_figures/FIGURE_10.pdf", as(pdf) replace
restore

! $fpost/fpost "$dir_figures/FIGURE_10.pdf"

clear
cap log close

! $fpost/fpost "$dir_logfiles/$logname.log"
