set matsize 11000 
 
capture log close
clear all
set more off
cd /path/data

global OUTPUT /path/output

graph set window fontface Helvetica

local xxx=c(current_date)
local yyy=subinstr("`xxx'", " ", "_", .)
di "`yyy'"

******************************
******************************
******************************
global USER user
global logname FE_REGS_`yyy'_$USER
global pre_reg pre_reg_v1_September_2019_100pct
global fpost /user/$USER


cap n ! mkdir $OUTPUT/tables/$logname
cap n ! mkdir $OUTPUT/figures/$logname

cap mkdir $OUTPUT/tables_round3
cap mkdir $OUTPUT/figures_round3
cap mkdir $OUTPUT/log_round3

global dir_logfiles $OUTPUT/log_round3
global dir_tables   $OUTPUT/tables_round3
global dir_figures  $OUTPUT/figures_round3

log using $dir_logfiles/$logname.log, replace
di "$S_DATE"


**************************** PROGRAMS *****************************************************************
cap program drop rank
	program define rank
	args vartorank byvar howmanyp
	cap drop rrr nnn
	egen rrr=rank(`vartorank'),by(`byvar') unique
	egen nnn=count(`vartorank'),by(`byvar') 
	cap drop q`howmanyp'_`vartorank'
	gen q`howmanyp'_`vartorank'=ceil((rrr/nnn)*`howmanyp')
	drop rrr nnn
end

cap program drop trim
	program define trim
	args vartotrim ltrim htrim
		foreach vvv in `vartotrim' {
			qui:{
				cap drop aux*
				gen aux=`vvv'
				forvalues yyy=2005(1)2015{
					_pctile aux if year==`yyy', p(`ltrim' `htrim')
					replace aux=. if year==`yyy' & inrange(aux,r(r1), r(r2))==0 
				}
				cap drop t_`vvv'
				gen t_`vvv'=aux
			}
			disp "trim `vvv' done"
		}
end
***************************************************************************************************


*********************************************************************************************************************************
global EDUCDEMO 	educ_year missing_educ econdegree male 	Dage* work partnerchangeD Dcounty* Dmarital* 
global EDUCDEMO_FE  					       				Dage* work partnerchangeD Dcounty* Dmarital* 

global SHARES_FW 	Lmf_share Lds_share Lbo_share Lfx_share Loc_share
global SHARES_FW_Y 	mf_fw_y* ds_fw_y* bo_fw_y* fx_fw_y* oc_fw_y*

global SHARES_NW 	Lmf_share2 Lds_share2 Lbo_share2 Lfx_share2 Loc_share2 Lpe_share2 Lhs_share2 Ldbm_share2 Ldbc_share2 Ldbs_share2
global SHARES_NW_Y 	mf_nw_y* ds_nw_y* fx_nw_y* bo_nw_y* oc_nw_y* pe_nw_y* hs_nw_y* dbc_nw_y* dbs_nw_y* dbm_nw_y* 

*********************************************************************************************************************************
global BETA_VARS	partA BPEPart BetaCountyHousePart Beta BetaPE  BetaCountyHouse
global BETA_VARS_Y	partA BPEPart BetaCountyHousePart Beta_y* BetaPE_y* BetaCountyHouse_y*
*********************************************************************************************************************************

***************************************************************************************************
global keepvars age marital county educ_length educ_type lnr year  hhid noise_hhid noise_lnr male work t_rr* ///
		q100* house_h educ_year missing_educ partnerchangeD ///
		Beta Alpha partA b_year todropNW* fw cpi inflation HH_size ///
		mfund_h tot_val_end_h otherW_abroad_sub_h bonds_h out_claims_h deposits_h ///
		PEVAL* house_h debt*h nfw*_h nw*_h gw*_h fw*_h econdegree

scalar define method=2	/*1=BCS, 2=DRE */
***************************************************************************************************


u $keepvars using  $pre_reg,clear

if method==2	{
	cap ren *_DRE *
	cap ren *_DRE_* *_*
	cap ren *_TAX *
	cap ren *_TAX_* *_*
}
else if method==1	{
	cap ren *_BCS *
	cap ren *_BCS_* *_*
}

*CONSTRUCT DUMMIES
qui tab age, g(Dage)
qui tab marital, g(Dmarital)
qui tab county, g(Dcounty)
qui tab educ_length, gen(Deducl)
qui tab educ_type, gen(Deduct)
g reD=house_h>0

cap drop Dyear_short*
cap drop year_short

*controls for fixed effect regression, 2004 isn't part of the regression
gen year_short = year if year > 2004 
tab year_short, gen(Dyear_short)

*Follow Deaton-Paxson JPE
forvalues i=4/11 {
	g dyear_short`i'= Dyear_short`i'-((`i'-1)*Dyear_short3-(`i'-2)*Dyear_short2)
	}

label variable male "Male"
label variable work "Employed"
label variable econdegree "Econ/Business education"

***RETURNS IN PERCENTAGE TERMS
gen T_rr_fw 	= t_rr_fw*100
gen T_rr_nw 	= t_rr_nw*100
gen T_rr_nfw 	= t_rr_nfw*100
gen T_rr_atnw 	= t_rr_atnw*100
gen T_rr_db 	= t_rr_db*100
gen T_rr_pe 	= t_rr_pe*100
gen T_rr_gw 	= t_rr_gw*100
gen T_rr_hs 	= t_rr_hs*100
gen T_rr_bcs	= t_rr_nw_BCS*100    

*ranks are for q100Lfw and q100Lnw, THIS SETS EXCLUDED PERCENTILE
fvset base 1 q100Lfw
fvset base 1 q100Lnw

***Trims Beta values
qui su Beta if year > 2004 & partA == 1, det
replace Beta = . if Beta > r(p99) & partA == 1
replace Beta = . if Beta < r(p1) & partA == 1 & Beta != 0

forvalues j=2005(1)2015	{
	qui g Beta_y`j'=Beta*(year==`j')
	}

***wrt FW
gen mf_share = mfund_h/fw_h
gen ds_share = (tot_val_end_h)/fw_h
gen fx_share = (otherW_abroad_sub_h)/fw_h
gen bo_share = bonds_h/fw_h
gen oc_share = (out_claims_h)/fw_h
gen dp_share = (deposits_h)/fw_h

***wrt NW
**(excluded category is share from safe assets)
gen mf_share2  = (mfund_h)/gw_h
gen ds_share2  = (tot_val_end_h)/gw_h
gen fx_share2  = (otherW_abroad_sub_h)/gw_h
gen bo_share2  = bonds_h/gw_h
gen oc_share2  = (out_claims_h)/gw_h
gen dp_share2  = (deposits_h)/gw_h
gen pe_share2  = PEVAL_h/gw_h
gen hs_share2  = house_h/gw_h
gen db_share2  = debt_h/gw_h
gen dbm_share2 = debt_oth_h/gw_h
gen dbc_share2 = debt_cons_h/gw_h
gen dbs_share2 = debt_stud_h/gw_h

xtset lnr year
foreach x of varlist mf_share-dbs_share2 {
	qui g L`x' = l.`x'
}

g Ldbc_share2_nowins=Ldbc_share2
g Ldbs_share2_nowins=Ldbs_share2
g Ldbm_share2_nowins=Ldbm_share2
replace Ldbc_share2 = 10 if Ldbc_share2 > 10 & Ldbc_share2 < .		/*Winsorize top leverage at 10*/
replace Ldbm_share2 = 10 if Ldbm_share2 > 10 & Ldbm_share2 < .		/*Winsorize top leverage at 10*/
replace Ldbs_share2 = 10 if Ldbs_share2 > 10 & Ldbs_share2 < .		/*Winsorize top leverage at 10*/

foreach x in mf ds fx bo oc dp {
	forvalues j=2005(1)2015	{
		qui g `x'_fw_y`j'=L`x'_share*(year==`j')
		qui g `x'_nw_y`j'=L`x'_share2*(year==`j')
}
}
foreach x in pe hs db dbc dbs dbm {
	forvalues j=2005(1)2015	{
		qui g `x'_nw_y`j'=L`x'_share2*(year==`j')
}
}

drop if todropNW == 1

qui tab q100Lfw, g(DLfw)
qui tab q100Lnw, g(DLnw)

**************CREATE RUNNING SAMPLE *********************************************
qui reg T_rr_fw $SHARES_FW dyear_short* $EDUCDEMO DLfw* Beta partA if year > 2004
gen FWsample = 1 if e(sample) == 1

lab var Lmf_share "Mutual fund share" 
lab var Lds_share "Direct stockh. share"
lab var Lbo_share "Bonds share"
lab var Lfx_share "Foreign w. share"
lab var Loc_share "Outst. cl. share"
lab var Lmf_share2 "Mutual fund share" 
lab var Lds_share2 "Direct stockh. share"
lab var Lpe_share2 "Private equity share"
lab var Lbo_share2 "Bonds share"
lab var Lfx_share2 "Foreign w. share"
lab var Loc_share2 "Outst.cl. share"
lab var Alpha "Average $\alpha$"
lab var Beta "Average $\beta$"
lab var Lhs_share2 "Housing share"
lab var Ldbm_share2 "LeverageMORT"
lab var Ldbc_share2 "LeverageCONS"
lab var Ldbs_share2 "LeverageSTUD"

****Merge in Housing AND PE Betas - no trimming needed
sort lnr year
cap drop _merge
merge 1:1 lnr year using /path/data/AlphaBetaCountyHousing0315, keep(match master)
replace BetaCountyHousePart = 0 if BetaCountyHousePart == .
replace BetaCountyHouse = 0 if BetaCountyHousePart == 0
cap drop _merge

merge 1:1 lnr year using /path/data/lnr_year_Alpha_Beta_PE_0515, keep(match master)
gen BPEPart = 1 if BetaPE > 0 & BetaPE < .
replace BPEPart = 0 if BPEPart == . 
replace BetaPE = 0 if BPEPart == 0
cap drop _merge

foreach x in BetaPE BetaCountyHouse {
	forvalues j=2005(1)2015	{
		qui g `x'_y`j'=`x'*(year==`j')
}
}

lab var BetaPE "Average $\beta$ PE"
lab var BetaCountyHouse "Average $\beta$ Housing"


keep 	$EDUCDEMO $SHARES_NW $SHARES_NW_Y $SHARES_FW $SHARES_FW_Y county dyear_short* DLnw* DLfw* FWsample hhid lnr ///
	t_rr_hs	T_rr* t_rr_nw_kD house_h PEVAL_h nw_h year debt_* t_rr_gw HH_size q100Lnw q100Lfw reD pe_share2 age  ///
	$BETA_VARS $BETA_VARS_Y
	
/*Save intermediate dataset to reduce memory issues*/
	
save select_$pre_reg,replace			

****************************************************************************************************************************


****************************************************************************************************************************
**************************** F E    R E G R E S S I O N S ******************************************************************
****************************************************************************************************************************

u select_$pre_reg , clear			

***********************NET WORTH
****************************************************************************************************************************
	eststo clear
	reg T_rr_nw  	$EDUCDEMO  $SHARES_NW 	dyear_short* DLnw* $BETA_VARS 	if FWsample == 1 ,cluster(hhid)
	eststo nwolsb , noesample 
		
	reg T_rr_nw  	$EDUCDEMO  $SHARES_NW_Y dyear_short* DLnw* $BETA_VARS_y if FWsample == 1,cluster(hhid)
	eststo nwolsbt , noesample
		
	areg T_rr_nw $EDUCDEMO_FE $SHARES_NW_Y  dyear_short* DLnw* $BETA_VARS_y	if FWsample == 1, abs(lnr) cluster(hhid)
	eststo nwfebt , noesample
	predict FE_r_nw, d			/*Save FE*/
	predict xbd_r_nw, xbd		/*Save Xbeta*/
	predict res_r_nw, r			/*Save non-FE residuals*/
	
**************** TABLE 4 ********************************************************************************
	esttab  nwolsb nwolsbt nwfebt using "$dir_tables/TABLE_4.tex",nostar se(4) b(4) nogaps ar2 label ///
		keep(educ_year econdegree male $SHARES_NW Beta BetaPE BetaCountyHouse) replace
*********************************************************************************************************
	
	! $fpost/fpost "$dir_tables/TABLE_4.tex"


*************************************************************
****** Financial Wealth
*************************************************************
	eststo clear
	reg T_rr_fw  $EDUCDEMO 	  reD $SHARES_FW_Y 	dyear_short* DLfw* partA Beta_y* if FWsample == 1, cluster(hhid)
	eststo olsbt , noesample
	areg T_rr_fw $EDUCDEMO_FE reD $SHARES_FW_Y 	dyear_short* DLfw* partA Beta_y* if FWsample == 1, abs(lnr) cluster(hhid)
	eststo febt , noesample
	predict FE_r_fw, d
	predict xbd_r_fw, xbd
	predict res_r_fw, r
	
	esttab olsbt febt using "$dir_tables/TABLE_6A.tex",nostar se(4) b(4) nogaps ar2 label ///
		keep(educ_year econdegree male ) replace
	! $fpost/fpost "$dir_tables/TABLE_6A.tex"

******************************************************************************
****** HOUSING
******************************************************************************
	eststo clear
	reg T_rr_hs $EDUCDEMO hs_nw_y* dyear_short* DLnw*    	if FWsample == 1,  cluster(hhid)
	eststo hsolsbt , noesample
	areg T_rr_hs  $EDUCDEMO_FE hs_nw_y* dyear_short*  DLnw*   if FWsample == 1, abs(lnr) cluster(hhid)
	eststo hsfebt , noesample
	predict FE_r_hs, d

	esttab  hsolsbt hsfebt using "$dir_tables/TABLE_6C.tex",nostar se(4) b(4) nogaps ar2 label ///
		keep(educ_year econdegree male) replace
	! $fpost/fpost "$dir_tables/TABLE_6C.tex"
	
******************************************************************************

******************************************************************************
****** Debt
******************************************************************************

	gen dem_sh = debt_oth_h/debt_h
	gen dec_sh = debt_cons_h/debt_h
	gen des_sh = debt_stud_h/debt_h
	sort lnr year
	foreach x in dem dec des {
		gen L`x'_sh = l.`x'_sh
	}

	drop dem_sh-des_sh

foreach x in dem dec des {
	forvalues j=2005(1)2015	{
		qui g `x'_db_y`j'=L`x'_sh*(year==`j')
}
}

	eststo clear
	reg T_rr_db $EDUCDEMO dem_db_y* des_db_y* dec_db_y*  dyear_short* DLnw*    if FWsample == 1,  cluster(hhid)
	eststo dbolsbt , noesample
	areg T_rr_db  $EDUCDEMO_FE dem_db_y* des_db_y* dec_db_y*  dyear_short*  DLnw*   if FWsample == 1, abs(lnr) cluster(hhid)
	eststo dbfebt , noesample
	predict FE_r_db, d

	esttab dbolsbt dbfebt using "$dir_tables/TABLE_6D.tex",nostar se(4) b(4) nogaps ar2 label ///
		keep(educ_year econdegree male ) replace
	! $fpost/fpost "$dir_tables/TABLE_6D.tex"

	drop dem_db_y* des_db_y* dec_db_y*

******************************************************************************
****** PE
******************************************************************************
	sort lnr year 
	merge lnr year using "/path/data/temp_extra_pe_info"		/*This is a dataset that records the number of businesses owned in each year*/
	tab _merge
	drop if _merge==2
	drop _merge
	sort lnr
	merge lnr using "/path/data/temp_numb_y_pe"				/*This is a dataset that records n=the number of years with PE experience since 1993. Experience in year t requires having non-registered stocks>0 in year t. */
	tab _merge
	drop if _merge==2
	drop _merge
	gen haspe=pe_share2>0 & pe_share2<.
	sort lnr year
	qby lnr: replace haspe=sum(haspe)
	gen z=n
	egen nexp=rsum(z haspe)															/*now adds years of experience as PE guy after 2004, cumulative*/
	drop z n haspe 

	gen exp_econ=nexp*econdegree
	gen exp_educ=nexp*educ_year
	gen multiple_bus=n_bus>0 & n_bus!=.

***********************************************************************************************************
global EDUCDEMO_PE 	educ_year missing_educ econdegree male work partnerchangeD Dcounty* Dmarital* 		/*Use experience as PE person, instead of age dummies*/
***********************************************************************************************************

	eststo clear
	reg T_rr_pe   $EDUCDEMO_PE i.nexp pe_nw_y*  dyear_short* DLnw* if FWsample == 1,  cluster(hhid)
	eststo peolsbt , noesample
	areg T_rr_pe  $EDUCDEMO_PE i.nexp pe_nw_y*  dyear_short* DLnw* if FWsample == 1, abs(lnr) cluster(hhid)
	eststo pefebt , noesample
	predict FE_r_pe, d

	esttab  peolsbt pefebt using "$dir_tables/TABLE_6B.tex",nostar se(4) b(4) nogaps ar2 label ///
		keep(educ_year econdegree male ) replace
	! $fpost/fpost "$dir_tables/TABLE_6B.tex"

	cap drop exp_econ exp_educ nexp multiple_bus 	
	

***********************************************************************************************************
*********RETURN TO NET WORTH, CONSTANT RETURN TO DEPOSITS **********  
g T_rr_nwk=t_rr_nw_kD*100

eststo clear
reg T_rr_nwk $EDUCDEMO $SHARES_NW_Y dyear_short* DLnw* 		$BETA_VARS_Y	 if FWsample == 1,  cluster(hhid)
eststo nwolsbt , noesample
areg T_rr_nwk $EDUCDEMO_FE $SHARES_NW_Y  dyear_short*  DLnw* 	$BETA_VARS_Y	 if FWsample == 1, abs(lnr) cluster(hhid)
eststo nwfebt , noesample
esttab nwolsbt nwfebt using "$dir_tables/TABLE_5B.tex",nostar se(4) b(4) nogaps ar2 label ///
	keep(educ_year econdegree male) replace

! $fpost/fpost "$dir_tables/TABLE_5B.tex"
******************************************************************************
***********************************************************************************************************

***********************************************************************************************************
******************************************************************************
*********RETURN TO NET WORTH, USING THE ALTERNATIVE PE MEASURE *********************** 

eststo clear
reg T_rr_bcs 	$EDUCDEMO 		$SHARES_NW_Y dyear_short* DLnw* 		$BETA_VARS_Y	if FWsample == 1,  cluster(hhid)
eststo nwolsbt , noesample
areg T_rr_bcs 	$EDUCDEMO_FE 	$SHARES_NW_Y dyear_short*  DLnw*    	$BETA_VARS_Y	 if FWsample == 1, abs(lnr) cluster(hhid)
eststo nwfebt , noesample
esttab nwolsbt nwfebt using "$dir_tables/TABLE_5C.tex",nostar se(4) b(4) nogaps ar2 label ///
	keep(educ_year econdegree male) replace

! $fpost/fpost "$dir_tables/TABLE_5C.tex"
***********************************************************************************************************
******************************************************************************

***********************************************************************************************************
******BASELINE REGRESSIONS - After Tax Net Worth
***********************************************************************************************************
eststo clear
reg T_rr_atnw  $EDUCDEMO $SHARES_NW dyear_short* DLnw*  	$BETA_VARS 	if FWsample == 1,cluster(hhid)
eststo nwolsb  , noesample
reg T_rr_atnw $EDUCDEMO $SHARES_NW_Y  dyear_short* DLnw*  	$BETA_VARS_Y	 if FWsample == 1,  cluster(hhid)
eststo nwolsbt , noesample
areg T_rr_atnw  $EDUCDEMO_FE $SHARES_NW_Y   dyear_short*  DLnw* $BETA_VARS_Y	 if FWsample == 1, abs(lnr) cluster(hhid)
eststo nwfebt , noesample
predict FE_r_nw_at, d
predict xbd_r_nw_at, xbd
predict res_r_nw_at, r

esttab nwolsb nwolsbt nwfebt using "$dir_tables/TABLE_OA1.tex",nostar se(4) b(4) nogaps ar2 label ///
	keep(educ_year econdegree male $SHARES_NW Beta BetaPE  BetaCountyHouse) replace
! $fpost/fpost "$dir_tables/TABLE_OA1.tex"
******************************************************************************

********************SAVE DATASET FOR FE PICTURES AND STATS **********************************************************
keep lnr T_rr_* year xbd* res* FE_r_* q100Lnw q100Lfw FWsample hhid t_rr* HH_size age male econdegree educ_y L*share2

egen Ldb_share2=rsum(Ldbc_share2 Ldbs_share2 Ldbm_share2)

*****************CREATE VARS TO USE FOR LATER ANALYSIS
foreach x in hs db pe {
	egen has`x'=sum(L`x'_share2>0 & L`x'_share2<.),by(lnr)
	egen n`x'=sum(L`x'_share2<.),by(lnr)
	gen always`x'=has`x'==n`x'
	gen ever`x'=has`x'>0
}

foreach x in fw nw {
	egen top10`x'=sum(q100L`x'>90 & q100L`x'<.),by(lnr)
	egen n`x'=sum(q100L`x'<.),by(lnr)
	gen alwaystop10`x'=top10`x'==n`x'
	gen evertop10`x'=top10`x'>0
	egen top1`x'=sum(q100L`x'>99 & q100L`x'<.),by(lnr)
	gen alwaystop1`x'=top1`x'==n`x'
	gen evertop1`x'=top1`x'>0
}

gen rp=(Lmf_share+Lds_share+Lpe_share2+Lfx_share)>0
replace rp=. if Lmf_share==.
egen riskpart=sum(rp),by(lnr)
egen np=sum(rp!=.),by(lnr)
gen ever_risky=riskpart>0
gen always_risky=riskpart==np

merge 1:1 lnr year using $pre_reg, keepusing(q100_L5nw)
drop if year == 2004
cap drop _merge

save SELECT_DATASET_W_FE, replace
*********************************************************************************************************************


**********************************************
***************** ADD DC TO NET WEALTH MEASURE
************************************************

u select_$pre_reg, replace

***need the numerators for recreating shares...
merge 1:1 lnr year using $pre_reg, keep(match master) ///
	keepusing(mfund_h tot_val_end_h otherW_abroad_sub_h bonds_h out_claims_h deposits_h PEVAL* house_h debt_oth_h debt_cons_h debt_stud_h)

cap drop _merge
	
merge 1:1 lnr year using dc_variables_for_FE

tab year _merge
drop if _merge == 2
cap gen T_rr_nw_ext   = t_rr_nw_ext  *100
keep if T_rr_nw_ext!=.

*redo shares
drop L*share2*
drop d*20* 

**(excluded category is share from safe assets)
gen mf_share3  = (mfund_h)/extended_gw_h 
gen ds_share3  = (tot_val_end_h)/extended_gw_h 
gen fx_share3  = (otherW_abroad_sub_h)/extended_gw_h 
gen bo_share3  = bonds_h/extended_gw_h 
gen oc_share3  = (out_claims_h)/extended_gw_h 
gen dp_share3  = (deposits_h)/extended_gw_h 
gen pe_share3  = PEVAL_h/extended_gw_h 
gen hs_share3  = house_h/extended_gw_h 
gen db_share3  = debt_h/extended_gw_h 
gen dc_share3  = DC_w_h/extended_gw_h 
gen dbm_share3 = debt_oth_h/extended_gw_h 
gen dbc_share3 = debt_cons_h/extended_gw_h 
gen dbs_share3 = debt_stud_h/extended_gw_h 

xtset lnr year
foreach x of varlist mf_share3-dbs_share3 {
	gen L`x' = l.`x'
}

g Ldbc_share3_nowins=Ldbc_share3
g Ldbs_share3_nowins=Ldbs_share3
g Ldbm_share3_nowins=Ldbm_share3
replace Ldbc_share3 = 10 if Ldbc_share3 > 10 & Ldbc_share3 < .
replace Ldbm_share3 = 10 if Ldbm_share3 > 10 & Ldbm_share3 < .
replace Ldbs_share3 = 10 if Ldbs_share3 > 10 & Ldbs_share3 < .

foreach x in mf ds oc dp pe fx bo hs db dc dbc dbs dbm {
	forvalues j=2006(1)2014	{
		qui g `x'_nwx_y`j'=L`x'_share3*(year==`j')
	}
}

global SHARES_DCNW_Y 	mf_nwx_y* ds_nwx_y* fx_nwx_y* bo_nwx_y* oc_nwx_y* pe_nwx_y* hs_nwx_y* dc_nwx_y* dbc_nwx_y* dbs_nwx_y* dbm_nwx_y* 

******************************************************************************
eststo clear
reg T_rr_nw_ext $EDUCDEMO $SHARES_DCNW_Y  dyear_short* DLnw*  partA $BETA_VARS_Y	 if FWsample == 1,  cluster(hhid)
eststo nwolsbt , noesample
areg T_rr_nw_ext  $EDUCDEMO_FE $SHARES_DCNW_Y   dyear_short*  DLnw* $BETA_VARS_Y	 if FWsample == 1, abs(lnr) cluster(hhid)
eststo nwfebt , noesample

******************************************************************************
esttab  nwolsbt nwfebt using "$dir_tables/TABLE_5D.tex",nostar se(4) b(4) nogaps ar2 label ///
	keep(educ_year econdegree male ) replace
! $fpost/fpost  "$dir_tables/TABLE_5D.tex"
******************************************************************************
clear


**********************************FE PICTURES *****************************************************
***************************************************************************************************
***************************************************************************************************

***************************************************************************************************
*DATASET TO BE USED LATER
***************************************************************************************************
u L5nw_TAX lnr year age using $pre_reg if year == 2005,clear
	drop year
	gen Cohort = 2005 - age

	bys  Cohort (L5nw_TAX): gen nnn=_n
	bys  Cohort (L5nw_TAX): gen NNN=_N
	gen qq=nnn/NNN
	gen q5yC100wealth=ceil(qq*100)
	replace q5yC100wealth = . if Cohort == . 
	drop nnn NNN qq

	label var q5yC100wealth "net wealth rank in 2000-2004, by cohort"
	keep lnr q5yC100wealth
	bysort lnr: keep if _n ==1
save nw_5years_rank_Cohort_in_2004, replace
***************************************************************************************************




************HISTOGRAMS AND FE STATS DONE ON THE BALANCED SAMPLES OF EACH RETURN FE
*********************************************************************************************************************
u SELECT_DATASET_W_FE, replace
*********************************************************************************************************************

cap eststo clear

preserve
	keep if FE_r_nw!=.
	bys lnr: g bal_s=[_N]
	keep if bal_s==11
	keep if year==2005
	qui su FE_r_nw
	g aaa_nw=FE_r_nw-r(mean)
	lab var aaa "Net worth"
	estpost tabstat aaa, s(mean sd sk k p10 p25 p50 p75 p90 count) columns(statistics)
**********************TABLE 7A*******************************************************************************************************
	esttab using $dir_tables/TABLE_7A1.tex , cells("mean(fmt(2)) sd skewness kurtosis p10 p25 p50 p75 p90 count(fmt(%15.0fc))") ///
	nomtitles nonumbers obslast label sfmt(fmt(a3)) noobs replace
	! $fpost/fpost "$dir_tables/TABLE_7A1.tex"
*************************************************************************************************************************************
	winsor FE_r_nw,gen(xxx_r_nw) p(0.01)
**********************FIGURE 8 *******************************************************************************************************
	hist xxx_r_nw,graphr(c(white)) xtitle(" ") color(ltblue) frac title("") 
	graph export "$dir_figures/FIGURE_8.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_8.pdf"
*************************************************************************************************************************************
restore

preserve
	keep if FE_r_nw_at!=.
	bys lnr: g bal_s=[_N]
	keep if bal_s==11
	keep if year==2005
	qui su FE_r_nw_at
	g aaa_nwat=FE_r_nw_at-r(mean)
	lab var aaa "After-tax net worth"
**********************TABLE 7A*******************************************************************************************************
	estpost tabstat aaa, s(mean sd sk k p10 p25 p50 p75 p90 count) columns(statistics)
	esttab using $dir_tables/TABLE_7A2.tex , cells("mean(fmt(2)) sd skewness kurtosis p10 p25 p50 p75 p90 count(fmt(%15.0fc))") ///
	nomtitles nonumbers obslast label sfmt(fmt(a3)) noobs replace
	! $fpost/fpost "$dir_tables/TABLE_7A2.tex"
*************************************************************************************************************************************
restore

preserve
	keep if FE_r_fw!=.
	bys lnr: gen bal_s=[_N]
	keep if bal_s==11
	keep if year==2005
	qui su FE_r_fw
	g aaa_fw=FE_r_fw-r(mean)
	lab var aaa "Financial wealth"
**********************TABLE 7A*******************************************************************************************************
	estpost tabstat aaa, s(mean sd sk k p10 p25 p50 p75 p90 count) columns(statistics)
	esttab using $dir_tables/TABLE_7A3.tex 	, cells("mean(fmt(2)) sd skewness kurtosis p10 p25 p50 p75 p90 count(fmt(%15.0fc))") ///
	nomtitles nonumbers obslast label sfmt(fmt(a3)) noobs replace
	! $fpost/fpost "$dir_tables/TABLE_7A3.tex"	
*************************************************************************************************************************************
	winsor FE_r_fw,gen(yyy_r_fw) p(0.01)
	hist yyy_r_fw,graphr(c(white)) xtitle(" ") title("Distrib. of FE(ret. to fin. wealth)") saving(a_nodem,replace)
restore

preserve
	keep if FE_r_pe!=.
	bys lnr: g bal_s=[_N]
	keep if bal_s==11
	keep if year==2005
	qui su FE_r_pe
	g aaa_pe=FE_r_pe-r(mean)
	lab var aaa "Private equity"
**********************TABLE 7A*******************************************************************************************************
	estpost tabstat aaa, s(mean sd sk k p10 p25 p50 p75 p90 count) columns(statistics)
	esttab using $dir_tables/TABLE_7A4.tex 	, cells("mean(fmt(2)) sd skewness kurtosis p10 p25 p50 p75 p90 count(fmt(%15.0fc))") ///
	nomtitles nonumbers obslast label sfmt(fmt(a3)) noobs replace
	! $fpost/fpost "$dir_tables/TABLE_7A4.tex"
*************************************************************************************************************************************
	winsor FE_r_pe,gen(zzz_r_pe) p(0.01)
	hist zzz_r_pe,graphr(c(white)) xtitle(" ") title("Distrib. of FE(ret. to PE)") saving(b_nodem,replace)
restore

preserve
	keep if FE_r_hs!=.
	bys lnr: gen bal_s=[_N]
	keep if bal_s==11
	keep if year==2005
	qui su FE_r_hs
	g aaa_hs=FE_r_hs-r(mean)
	lab var aaa "Housing"
**********************TABLE 7A*******************************************************************************************************
	estpost tabstat aaa, s(mean sd sk k p10 p25 p50 p75 p90 count) columns(statistics)
	esttab using $dir_tables/TABLE_7A5.tex 	, cells("mean(fmt(2)) sd skewness kurtosis p10 p25 p50 p75 p90 count(fmt(%15.0fc))") ///
	nomtitles nonumbers obslast label sfmt(fmt(a3)) noobs replace
	! $fpost/fpost "$dir_tables/TABLE_7A5.tex"
*************************************************************************************************************************************
	winsor FE_r_hs,gen(yyy_r_hs) p(0.01)
	hist yyy_r_hs,graphr(c(white)) xtitle(" ") title("Distrib. of FE(ret. to housing)") saving(c_nodem,replace) 
restore

preserve
	keep if FE_r_db!=.
	bys lnr: gen bal_s=[_N]
	keep if bal_s==11
	keep if year==2005
	qui su FE_r_db
	g aaa=FE_r_db-r(mean)
	lab var aaa "Debt"
**********************TABLE 7A*******************************************************************************************************
	estpost tabstat aaa, s(mean sd sk k p10 p25 p50 p75 p90 count) columns(statistics)
	esttab using $dir_tables/TABLE_7A6.tex , cells("mean(fmt(2)) sd skewness kurtosis p10 p25 p50 p75 p90 count(fmt(%15.0fc))") ///
	nomtitles nonumbers obslast label sfmt(fmt(a3)) noobs replace
	! $fpost/fpost "$dir_tables/TABLE_7A6.tex"
*************************************************************************************************************************************
	winsor FE_r_db,gen(xxx_r_db) p(0.01)
	hist xxx_r_db,graphr(c(white)) xtitle(" ") title("Distrib. of FE(cost of debt)") saving(d_nodem,replace)
restore
**********************FIGURE OA.20 *************************************************************************************************
graph combine a_nodem.gph b_nodem.gph c_nodem.gph d_nodem.gph, graphr(c(white)) nocopies
graph export "$dir_figures/FIGURE_OA20.pdf", as(pdf) replace
! $fpost/fpost "$dir_figures/FIGURE_OA20.pdf"
*************************************************************************************************************************************



*********************************************************************************************************************
***STATISTICS: FE NW GROUPING
*********************************************************************************************************************
u SELECT_DATASET_W_FE, replace
keep if FE_r_nw!=.
bys lnr: g bal_s=[_N]
keep if bal_s==11
keep if year==2005

save SELECT_DATASET_W_FE_BALANCED,replace

u SELECT_DATASET_W_FE_BALANCED,clear
cap drop _merge
merge m:1 lnr using  "/path/data/lnr_mlnr_flnr.dta", keep(match master)
cap drop _merge

ren lnr LNR

cap drop *merge
ren mlnr lnr
merge m:1 lnr using nw_5years_rank_Cohort_in_2004, keep(match master) 
ren q5yC mother_pctl_2004
ren lnr mlnr 

ren flnr lnr
cap drop *merge
merge m:1 lnr using nw_5years_rank_Cohort_in_2004, keep(match master) 
ren q5yC father_pctl_2004
ren lnr flnr

ren LNR lnr
egen maxfm=rmax(father_pctl mother_pctl)


	foreach x in nw {
		g FE_`x'_bus=FE_r_`x' if alwayspe==1
		g FE_`x'_top10nw=FE_r_`x' if evertop10nw==1
		g FE_`x'_highed=FE_r_`x' if educ_year>13
		g FE_`x'_econ=FE_r_`x' if econdegree==1
		g FE_`x'_risky=FE_r_`x' if ever_risky==1
		g FE_`x'_richpar=FE_r_`x' if maxfm>=90 & maxfm<.
	}


***TABLE 7B ************************************************************
	estpost tabstat FE_nw_bus FE_nw_top10nw FE_nw_richpar FE_nw_risky FE_nw_highed FE_nw_econ  , ///
	s(mean sd sk k p10 p25 p50 p75 p90 count) columns(statistics)
	esttab using $dir_tables/TABLE_7B.tex 	, ///
	cells("mean(fmt(2)) sd skewness kurtosis p10 p25 p50 p75 p90 count(fmt(%15.0fc))") nomtitles nonumbers obslast label sfmt(fmt(a3)) ///
	noobs replace
	! $fpost/fpost "$dir_tables/TABLE_7B.tex"
************************************************************************

	winsor FE_r_nw,gen(xxx_r_nw) p(0.005)
	
	g fernw_highE 	=xxx_r_nw if educ_year >=12
	g fernw_nohighE =xxx_r_nw if educ_year < 12
	g fernw_alwpe	=xxx_r_nw if alwayspe==1
	g fernw_noalwpe	=xxx_r_nw if alwayspe==0
	g fernw_be	=xxx_r_nw if econ==1 & educ_year>=12
	g fernw_nobe	=xxx_r_nw if (econ==0  & educ_year>=12)|educ_year<12
	g fernw_tp	=xxx_r_nw if evertop10nw==1
	g fernw_notp	=xxx_r_nw if evertop10nw==0
	g fernw_he	=xxx_r_nw if ever_risky==1
	g fernw_nohe	=xxx_r_nw if ever_risky==0
	g fernw_hs	=xxx_r_nw if alwayshs==1
	g fernw_nohs	=xxx_r_nw if alwayshs==0
	g fernw_db	=xxx_r_nw if everdb==1
	g fernw_nodb	=xxx_r_nw if everdb==0	
	
twoway (histogram xxx_r_nw if maxfm >= 90 & maxfm < . , bin(40) frac color(ltblue)   graphr(c(white)) plotregion(color(white)) )   ///
	       (histogram xxx_r_nw if maxfm > 0 & maxfm < 90,  bin(40) frac fcolor(none)   lcolor(black)   xtitle(" ")  ///
		legend(region(lcolor(white)) order(1 "Parent Top 10%" 2 "Parent Bottom 90%") cols(2)) saving(d,replace))	
	
twoway (histogram fernw_tp, bin(40) frac color(ltblue)  graphr(c(white)) plotregion(color(white)) )   ///
	       (histogram fernw_notp,  bin(40) frac fcolor(none)   lcolor(black)  xtitle(" ")  ///
		legend(region(lcolor(white)) order(1 "Ever Top 10%" 2 "Never Top 10%") cols(2)) saving(c,replace))	

twoway (histogram xxx_r_nw if always_risky == 1 , bin(40) frac color(ltblue)  graphr(c(white)) plotregion(color(white)) )   ///
       (histogram xxx_r_nw if always_risky == 0 , bin(40) frac fcolor(none)    lcolor(black)  xtitle(" ")  ///
	legend(region(lcolor(white)) order(1 "Risky assets" 2 "No risky assets") cols(2)) saving(a,replace))

twoway (histogram fernw_alwpe , bin(40) frac color(ltblue)  graphr(c(white)) plotregion(color(white)) )   ///
       (histogram fernw_noalwpe , bin(40) frac fcolor(none)    lcolor(black)  xtitle(" ")  ///
	legend(region(lcolor(white)) order(1 "Private business" 2 "No private business") cols(2)) saving(b,replace))
	
*************************FIGURE 9 **********************************************
	graph combine a.gph b.gph c.gph d.gph, iscale(0.6) graphr(c(white)) nocopies
	graph export "$dir_figures/FIGURE_9.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_9.pdf"
********************************************************************************
clear



****Various stats*****
************************************************************************
u SELECT_DATASET_W_FE, clear				/*Dataset from 2005 to 2015*/

*generate balanced panels in the fixed effects
foreach x in  nw fw nw_at {
	bys lnr: egen N_FE_r_`x' = total(FE_r_`x'!= .)
	replace FE_r_`x' = .  if N_FE_r_`x'   != 11			/*doesn't use unbalanced sample for stats*/
	gen u_`x' = FE_r_`x' + res_r_`x'
	}
	

***STATISTIC: (RATIO OF VAR fe/VAR error, RATIO OF VAR u/VAR error)
foreach x in nw  nw_at {
	qui su u_`x' if N_FE_r_`x' == 11
	scalar def varU=r(Var)
	qui su FE_r_`x' if N_FE_r_`x' == 11
	scalar def varF=r(Var)
	scalar def ratio_FU_`x'=varF/varU
	scalar def ratio_EU_`x'=(varU-varF)/varU
	scalar list ratio_FU_`x' ratio_EU_`x'
}

cap matrix drop output_nw output_atnw
matrix output_nw=ratio_FU_nw			/*1*/
matrix output_nw=output_nw\(ratio_EU_nw)		/*2*/
matrix colnames output_nw = nw

matrix output_atnw=ratio_FU_nw_at			/*1*/
matrix output_atnw=output_atnw\(ratio_EU_nw_at)		/*2*/
matrix colnames output_atnw = nw_at

************************************************************

keep if year == 2005

*****Balanced sample created here
drop if (FE_r_nw == . & FE_r_fw == .)

sort lnr

cap drop _merge
merge m:1 lnr using  "/path/data/lnr_mlnr_flnr.dta", keep(match master)

cap drop _merge
ren lnr LNR
ren mlnr lnr
ren FE* own_FE*
cap drop _merge
merge m:1 lnr using SELECT_DATASET_W_FE_BALANCED, keep(match master) keepusing(FE*)
ren FE* m_FE*
cap drop _merge
ren lnr mlnr
ren flnr lnr
merge m:1 lnr using SELECT_DATASET_W_FE_BALANCED, keep(match master) keepusing(FE*)
ren FE* f_FE*
ren lnr flnr 
ren LNR lnr
cap drop _merge

ren lnr LNR


foreach x in nw	nw_at {
	egen p_FE_`x' 	= rowmean(m_FE_r_`x' f_FE_r_`x')			/*average of mother and father FE*/
}

***************STATISTICS: CORRELATION FE(g), FE(g-1)
qui: 	corr own_FE_r_nw p_FE_nw
matrix temp = (r(rho))
matrix output_nw=output_nw\temp			/*3*/	

qui: 	corr own_FE_r_nw_at p_FE_nw_at
matrix temp = (r(rho))
matrix output_atnw=output_atnw\temp			/*3*/	

qui:reg own_FE_r_nw p_FE_nw
matrix V=e(V)
matrix temp = _b[p_FE_nw]\sqrt(V[1,1])		
matrix output_nw=output_nw\temp			/*4,5*/
qui:reg own_FE_r_nw_at p_FE_nw_at
matrix V=e(V)
matrix temp = _b[p_FE_nw_at]\sqrt(V[1,1])		
matrix output_atnw=output_atnw\temp			/*4,5*/


ren own_FE* FE*

g evertop10nw_at=evertop10nw
g alwaystop10nw_at=alwaystop10nw

***************STATISTICS: REGRESSION OF FE(g) ON NET WORTH PERCENTILE IN 2004
qui: reg FE_r_nw q100Lnw
matrix V=e(V)
matrix temp = _b[q100Lnw]\sqrt(V[1,1])		
matrix output_nw=output_nw\temp			/*6,7*/

qui: reg FE_r_nw_at q100Lnw
matrix V=e(V)
matrix temp = _b[q100Lnw]\sqrt(V[1,1])		
matrix output_atnw=output_atnw\temp			/*6,7*/

matrix rownames output_nw = varf_vare varu_vare ig_corr b_fe_fe1 se_b_fe_fe1 b_fe_pnw04 se_b_fe_pnw04 
matrix rownames output_atnw = varf_vare varu_vare ig_corr b_fe_fe1 se_b_fe_fe1 b_fe_pnw04 se_b_fe_pnw04 

**************TABLE 8 *************************************************************
frmttable using $dir_tables/TABLE_8A, statmat(output_nw) tex replace sdec(4)
! $fpost/fpost "$dir_tables/TABLE_8A.tex"
frmttable using $dir_tables/TABLE_8B, statmat(output_atnw) tex replace sdec(4)
! $fpost/fpost "$dir_tables/TABLE_8B.tex"
*******************************************************************************************************
clear

*******************************************************************************************************
****IG Correlation of FE pictures*****
*******************************************************************************************************

use SELECT_DATASET_W_FE_BALANCED,clear

g b_year=year-age

cap drop _merge
sort lnr
merge m:1 lnr using  "/path/data/lnr_mlnr_flnr.dta", keep(match master)

gen Cohort=b_year

foreach x in nw fw  {
	qui su FE_r_`x'
	replace FE_r_`x'=FE_r_`x'-r(mean)
	g FE`x'=FE_r_`x'
	sort year Cohort FE`x'
	bys year Cohort (FE`x'): gen nnn=_n
	bys year Cohort (FE`x'): gen NNN=_N
	gen qq=nnn/NNN
	gen q100FE`x'=ceil(qq*100)
	drop nnn NNN qq
}

preserve 
	cap drop flnr
	rename lnr flnr
	keep flnr q100FE* FE* year
	foreach var of varlist q100FEnw FEnw q100FEfw FEfw {
		cap ren `var' `var'_fath 
		}
	save temp, replace
restore

**Merge back:
cap drop _merge
merge m:1 flnr year using temp, keep(match master)
cap drop _merge
erase temp.dta


reg q100FEfw q100FEfw_fath
global sloperfw=round(_b[q100FEfw_fath],.01)
reg q100FEnw q100FEnw_fath
global slopernw=round(_b[q100FEnw_fath],.01)


lab var q100FEfw "Child's wealth return FE percentile"
lab var q100FEfw_f "Parent's wealth return FE percentile"
lab var q100FEnw "Child's wealth return FE percentile"
lab var q100FEnw_f "Parent's wealth return FE percentile"

**********************FIGURE OA.21 *******************************************************************************
binscatter q100FEfw q100FEfw_fath,n(100) ylabel(40(10)70) title("FE, return to fin. wealth") saving(a,replace) ///
		ytitle("Child avg. percentile") xtitle("Parent percentile") text(65 90 "Slope=$sloperfw") ms(oh)
graph export "$dir_figures/FIGURE_OA21A.pdf", as(pdf) replace
binscatter q100FEnw q100FEnw_fath,n(100) ylabel(40(10)70) title("FE, return to net worth") saving(b,replace) ///
		ytitle("Child avg. percentile") xtitle("Parent percentile") text(65 90 "Slope=$slopernw") ms(oh)
graph export "$dir_figures/FIGURE_OA21B.pdf", as(pdf) replace

! $fpost/fpost "$dir_figures/FIGURE_OA21A.pdf"
! $fpost/fpost "$dir_figures/FIGURE_OA21B.pdf"


***********************************AUTOCOVARIANCES****** (Figure OA.16)
u lnr year res_r_nw using SELECT_DATASET_W_FE, clear

replace res_r_nw=res_r_nw/100

tsset lnr year

foreach x in nw  {
	g dres_r_`x'=D.res_r_`x'
	gen autocov`x'0=dres_r_`x'^2
	}

foreach x in nw  {
forvalues j=1(1)9	{
	gen autocov`x'`j'=dres_r_`x'*L`j'.dres_r_`x'
	}
}

foreach x in nw  {
forvalues j=0(1)9	{
	reg autocov`x'`j'
	gen b`x'`j'=_b[_cons] 
	matrix V=e(V)
	gen cilow`x'`j'=_b[_cons]-1.96*sqrt(V[1,1])
	gen cihi`x'`j'=_b[_cons]+1.96*sqrt(V[1,1])
	}
}

keep in 1
keep bnw* cihi* cilow*
gen id=1
reshape long bnw cihinw cilownw ,i(id) j(order)

	lab var bnw "Autocov."
	lab var cilownw "Lower bound, 95% CI" 
	lab var cihinw "Upper bound, 95% CI" 
************FIGURE OA.19 *******************
	scatter bnw cilownw cihinw order,c(l l l) graphr(c(white)) legend(cols(3) size(small)) xtitle("Order")
	graph export "$dir_figures/FIGURE_OA19.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_OA19.pdf"


************************************************************************************************************************


clear
log close

cd $dir_logfiles
! $fpost/fpost FE_REGS*_$USER.log

