******Summary statistics file
set more off
set matsize 11000 
 
capture log close
clear all
set more off
cd /path/data  /*specify path for data*/
global OUTPUT /path/output /*specify path for output*/

graph set window fontface Helvetica

local xxx=c(current_date)
local yyy=subinstr("`xxx'", " ", "_", .)
di "`yyy'"

global USER user
global logname STATS_FIGURES_`yyy'_$USER
global pre_reg pre_reg_v1_September_2019_100pct

******************************
******************************
******************************
global fpost /users/$USER 

cap mkdir $OUTPUT/tables_round3
cap mkdir $OUTPUT/figures_round3
cap mkdir $OUTPUT/log_round3

global dir_logfiles $OUTPUT/log_round3
global dir_tables   $OUTPUT/tables_round3
global dir_figures  $OUTPUT/figures_round3

log using $dir_logfiles/$logname.log, replace
di "$S_DATE"

*********************************************************************************************
**************************** PROGRAMS *****************************************************************
cap program drop rank
	program define rank
	args vartorank byvar howmanyp
	cap drop rrr 
	cap drop nnn
	egen rrr=rank(`vartorank'),by(`byvar') unique
	egen nnn=count(`vartorank'),by(`byvar') 
	cap drop q`howmanyp'_`vartorank'
	gen q`howmanyp'_`vartorank'=ceil((rrr/nnn)*`howmanyp')
	drop rrr nnn
end

cap program drop trim
	program define trim
	args vartotrim ltrim htrim
		foreach vvv in `vartotrim' {
			qui:{
				cap drop aux*
				gen aux=`vvv'
				forvalues yyy=2005(1)2015{
					_pctile aux if year==`yyy', p(`ltrim' `htrim')
					replace aux=. if year==`yyy' & inrange(aux,r(r1), r(r2))==0 
				}
				cap drop t_`vvv'
				gen t_`vvv'=aux
			}
			disp "trim `vvv' done"
		}
end
***************************************************************************************************

*************************************************************************************************************************************
global keepvars_main debt fw lnr year todropNW* *_h t_rr* w_* marital educ* age size HH_size nom* den* male  ///
		 hhid *_h_avg inflation	q100* Alpha partAlpha risky_share L_risky_share *_ind nfw* econdegree l5*
global keepvars_pe_robust lnr year todropNW* *_h t_rr* HH_size hhid *_h_avg inflation pe_share q100* cpi* ///
		 nom_fw den_fw nom_nw* den_nw
global keepvars_digging lnr t_rr* *_h inflation year todropNW* q100* *_h_avg HH_size bus_inc 
global keepvars_sharpe male todropNW* year lnr fw_h_avg tbill q100* educ_year age econdegree r_fw r_fw_kD r_fw_kDB n_bus gw*_h PEVAL*
global keepvars_intergen q100* t_rr* year todropNW* lnr b_year HH_size *_h *_h_avg age educ* 
*************************************************************************************************************************************		

scalar define method=2	/*1=BCS (Alternative PE measure), 2=DRE (Baseline) */

***************************************************************************************************


**************************************SCALE DEPENCENCE REGRESSIONS***************
u $keepvars_main using $pre_reg,clear

if method==2	{
	cap ren *_DRE *
	cap ren *_DRE_* *_*
	cap ren *_TAX *
	cap ren *_TAX_* *_*
}
else if method==1	{
	cap ren *_BCS *
	cap ren *_BCS_* *_*
}

drop if year==2004
drop if todropNW==1


******************************************************
**********************Net worth
******************************************************
cap drop rrr nnn ratio

egen rrr=rank(nw_h),by(year) unique
egen nnn=count(nw_h),by(year) 
g ratio=(rrr/nnn)

gen centNW=ceil(ratio*100)
gen decNW=ceil(ratio*10)
cap drop alt_group2
gen alt_group2=.
replace alt_group2=0 if centNW<10 					/*bottom 20%*/
replace alt_group2=1 if centNW>=10 & decNW<=2 		/*bottom 20%*/
replace alt_group2=2 if centNW>=20 & decNW<=5 		/*21-50%*/
replace alt_group2=3 if decNW>5 & decNW<10 			/*50 to 90%*/
replace alt_group2=4 if decNW==10 & centNW<96 		/*90 to 95%*/
replace alt_group2=5 if centNW>95 & centNW<100 		/*95 to 99%*/
replace alt_group2=6 if centNW==100 & ratio<0.999 	/*99 to 99.9%*/
replace alt_group2=7 if ratio>=0.999 & ratio<0.9999 /*99.9 to 99.99%*/
replace alt_group2=8 if ratio>=0.9999 & ratio!=. 	/*99.9 to 99.99%*/
label define ag 0 "0-10%" 1 "10-20%" 2 "20-50%" 3 "50-90%" 4 "90-95%" 5 "95-99%" 6 "99-99.9%" 7 "99.9-99.99%" 8 "top 0.01%",replace
label values alt_group2 ag

***Shares out of GW	
gen sfsh_gw=(deposits_h+bonds_h+dep_abroad_sub_h+out_claims_h)/(gw_h)
gen pesh_gw=(PEVAL_h)/(gw_h)
gen hssh_gw=(house_h)/(gw_h)
gen rksh_gw=(tot_val_end_h+mfund_h+otherW_abroad_sub_h)/(gw_h)
gen levgw=log(gw_h)

gen odsh_gw = debt_oth_h/gw_h
gen sdsh_gw = debt_stud_h/gw_h
gen cdsh_gw = debt_cons_h/gw_h

foreach x in od sd cd { 
forvalues j=2004(1)2015	{
	qui su `x'sh_gw if year==`j',d
	replace `x'sh_gw=r(p99) if `x'sh_gw>r(p99) & `x'sh_gw<. & year==`j'		/*Trims extreme leverage values for descriptive stats*/
	}
}


****************************** TABLE 1A ******************************************************************************************************************
eststo clear
eststo: estpost tabstat sfsh_gw rksh_gw hssh_gw pesh_gw cdsh_gw  sdsh_gw  odsh_gw levgw,by(alt_group2) not
esttab using "$dir_tables/TABLE_1A.tex", ///
	cells("sfsh_gw(label(Safe) f(2)) rksh_gw(label(Risky) f(2)) hssh_gw(label(Housing) f(2)) pesh_gw(label(Private eq.) f(2)) cdsh_gw(label(Consumer debt) f(2)) sdsh_gw(label(Student debt) f(2)) odsh_gw(label(Long-term debt) f(2)) levgw(label(LogGW) f(2))") replace
! $fpost/fpost "$dir_tables/TABLE_1A.tex"
**********************************************************************************************************************************************************

**************************FIGURE OA.3 *******************************************************************************************
preserve
	gcollapse sfsh_gw rksh_gw hssh_gw pesh_gw cdsh_gw  sdsh_gw  odsh_gw, by(centNW)
	graph bar sfsh_gw rksh_gw hssh_gw pesh_gw , over(centNW,gap(0) ///
		label(alt angle(90) labsize(vsmall))) stack intensity(75) ///
		legend(label(1 "Safe")  label(2 "Risky") ///
		label(3 "Housing") label(4 "Priv.Eq.") cols(2) reg(lc(white)) size(small)) graphr(c(white)) ytitle(Share of gross wealth)
	graph export "$dir_figures/FIGURE_OA3_A.pdf", as(pdf) replace

	graph bar cdsh_gw  sdsh_gw  odsh_gw , over(centNW,gap(0) ///
		label(alt angle(90) labsize(vsmall))) stack intensity(75) ///
		bar(1,color(gs10)) bar(2,color(black)) bar(3,color(orange)) ///
		legend(label(1 "Consumpt.") label(3 "Long-term debt")  label(2 "Student") rows(1) reg(lc(white)) size(small)) ///
		graphr(c(white)) ytitle(Share of gross wealth)
	graph export "$dir_figures/FIGURE_OA3_B.pdf", as(pdf) replace
restore
! $fpost/fpost "$dir_figures/FIGURE_OA3_A.pdf"
! $fpost/fpost "$dir_figures/FIGURE_OA3_B.pdf"
**********************************************************************************************************************************************************

******************************************************
********************** Extended Net worth
******************************************************
cap drop rrr nnn ratio centNW decNW alt_group2 sfsh_gw-cdsh_gw

g nw_h_ext=nw_h+cabin_h+re_abroad_sub_h+boats_h+motor_h

egen rrr=rank(nw_h_ext),by(year) unique
egen nnn=count(nw_h_ext),by(year) 
g ratio=(rrr/nnn)

gen centNW=ceil(ratio*100)
gen decNW=ceil(ratio*10)
cap drop alt_group2
gen alt_group2=.
replace alt_group2=1 if centNW<20 						/*bottom 20%*/
replace alt_group2=2 if centNW>=20 & decNW<=5 			/*21-50%*/
replace alt_group2=3 if decNW>5 & decNW<10 				/*50 to 90%*/
replace alt_group2=4 if decNW==10 & centNW<96 			/*90 to 95%*/
replace alt_group2=5 if centNW>95 & centNW<100 			/*95 to 99%*/
replace alt_group2=6 if centNW==100 & ratio<0.999 		/*99 to 99.9%*/
replace alt_group2=7 if ratio>=0.999 & ratio<0.9999 	/*99.9 to 99.99%*/
replace alt_group2=8 if ratio>=0.9999 & ratio!=. 		/*99.9 to 99.99%*/
label define ag 1 "0-20%" 2 "20-50%" 3 "50-90%" 4 "90-95%" 5 "95-99%" 6 "99-99.9%" 7 "99.9-99.99%" 8 "top 0.01%",replace
label values alt_group2 ag
	
g gw_h_new=(fw_h+nfw_h+cabin_h+re_abroad_sub_h+boats_h+motor_h)

gen sfsh_gw=(deposits_h+bonds_h+dep_abroad_sub_h+out_claims_h)/(gw_h_new)
gen pesh_gw=(PEVAL_h)/(gw_h_new)
gen hssh_gw=(house_h)/(gw_h_new)
gen rksh_gw=(tot_val_end_h+mfund_h+otherW_abroad_sub_h)/(gw_h_new)
gen odsh_gw=(debt_oth_h)/(gw_h_new)
gen sdsh_gw=(debt_stud_h)/(gw_h_new)
gen cdsh_gw=(debt_cons_h)/gw_h_new
gen real_gw=(cabin_h+re_abroad_sub_h+boats_h+motor_h)/(gw_h_new)
gen levgw=log(gw_h_new)

foreach x in od sd cd { 
forvalues j=2004(1)2015	{
	qui su `x'sh_gw if year==`j',d
	replace `x'sh_gw=r(p99) if `x'sh_gw>r(p99) & `x'sh_gw<. & year==`j'
	}
}

**************************FIGURE OA.1 *******************************************************************************************
preserve
	gcollapse sfsh_gw rksh_gw  hssh_gw  pesh_gw  real_gw cdsh_gw  sdsh_gw  odsh_gw, by(centNW)
	graph bar sfsh_gw rksh_gw  hssh_gw  pesh_gw  real_gw, over(centNW,gap(0) ///
		label(alt angle(90) labsize(vsmall))) stack intensity(75) ///
		legend(label(1 "Safe")  label(2 "Risky") ///
		label(3 "Housing") label(4 "Priv.Eq.") label(5 "Other real w.") cols(3) reg(lc(white)) size(small)) graphr(c(white)) ytitle(Share of gross wealth)
	graph export "$dir_figures/FIGURE_OA1_A.pdf", as(pdf) replace
	
	graph bar cdsh_gw  sdsh_gw  odsh_gw , over(centNW,gap(0) ///
		label(alt angle(90) labsize(vsmall))) stack intensity(75) ///
		bar(1,color(gs10)) bar(2,color(black)) bar(3,color(orange)) ///
		legend(label(1 "Consumption") label(3 "Long-term debt")  label(2 "Student") rows(1) reg(lc(white)) size(small)) ///
		graphr(c(white)) ytitle(Share of gross wealth)
	graph export "$dir_figures/FIGURE_OA1_B.pdf", as(pdf) replace
restore
! $fpost/fpost "$dir_figures/FIGURE_OA1_A.pdf"
! $fpost/fpost "$dir_figures/FIGURE_OA1_B.pdf"

*****************************************************
**********************Financ. wealth 
******************************************************
cap drop rrr nnn ratio

egen rrr=rank(fw_h),by(year) unique
egen nnn=count(fw_h),by(year) 
gen ratio=(rrr/nnn)

gen centFW=ceil(ratio*100)
gen decFW=ceil(ratio*10)
cap drop alt_group
gen alt_group=.
replace alt_group=0 if centFW<=10 			/*bottom 10%*/
replace alt_group=1 if centFW>10 & decFW<=2		/*bottom 10%*/
replace alt_group=2 if centFW>20 & decFW<=5 		/*21-50%*/
replace alt_group=3 if decFW>5 & decFW<10 		/*50 to 90%*/
replace alt_group=4 if decFW==10 & centFW<96 		/*90 to 95%*/
replace alt_group=5 if centFW>95 & centFW<100 		/*95 to 99%*/
replace alt_group=6 if centFW==100 & ratio<0.999 	/*99 to 99.9%*/
replace alt_group=7 if ratio>=0.999 & ratio<0.9999 	/*99.9 to 99.99%*/
replace alt_group=8 if ratio>=0.9999 & ratio!=. 	/*99.9 to 99.99%*/
label define ag 0 "0-10%" 1 "10-20%" 2 "20-50%" 3 "50-90%" 4 "90-95%" 5 "95-99%" 6 "99-99.9%" 7 "99.9-99.99%" 8 "top 0.01%",replace
label values alt_group ag

***Shares out of FW
g dpdfh	=(deposits_h+dep_abroad_sub_h)/fw_h
g bonsh	=bonds_h/fw_h
g mutsh	=(mfund_h)/fw_h
g dirsh	=(tot_val_end_h)/fw_h
g ocsh	=(out_claims_h)/fw_h
g fxsh	=(otherW_abroad_sub_h)/fw_h
g level =log(fw_h)

***************************TABLE 1B ********************************************************************************************************
eststo clear
eststo: estpost tabstat dpdfh-fxsh level,by(alt_group) not
esttab using "$dir_tables/TABLE_1B.tex", cells("dpdfh(label(Deposits) f(2)) bonsh(label(Bonds) f(2)) mutsh(label(Mutual funds) f(2)) dirsh(label(Listed shares) f(2)) ocsh(label(Outst. claims) f(2)) fxsh(label(Foreign) f(2)) level(label(LogFW) f(2))") replace
! $fpost/fpost "$dir_tables/TABLE_1B.tex"
********************************************************************************************************************************************
***************************FIGURE OA.4 *****************************************************************************************************
preserve
	gcollapse dpdfh-fxsh,by(centFW)
	graph bar dpdfh-fxsh , over(centFW,gap(0) ///
		label(alt angle(90) labsize(vsmall))) stack intensity(75) ///
		legend( label(1 "Deposits")  label(4 "Direct stockh.") label(5 "Outst. cl.") ///
		label(3 "Mutual funds") label(2 "Bonds") label(6 "Foreign ass.") rows(2) reg(lc(white)) size(small)) graphr(c(white)) ///
		ytitle(Share of financial wealth)
	graph export "$dir_figures/FIGURE_OA4.pdf", as(pdf) replace
restore
! $fpost/fpost "$dir_figures/FIGURE_OA4.pdf"
********************************************************************************************************************************************



/********INDIVIDUAL STATISTICS */
	tab marital,gen(Dmarital)
	tab educ_len,gen(elcat)
	gen LTHS=educ_len<=2|educ_len==9
	gen HS=educ_len>=3 & educ_len<=5
	gen CE=educ_len>=6 & educ_len<=8
	lab var LTHS "Less than High School education"
	lab var HS "High School education"
	lab var CE "College education"
	lab var age "Age"
	lab var Dmarital3 "Married"
	lab var size "Family size"
******************************************************************************

******************************INDIVIDUAL LEVEL STATS**************************
	gen A_FinW=fw_h/HH_size
	gen A_Safe=safe_h/HH_size
	gen A_RiskF=(tot_val_end_h+mfund_h+otherW_abroad_sub_h)/HH_size
	gen A_NonfinW=(PEVAL_h+house_h)/HH_size
	gen A_RiskT=(tot_val_end_h+mfund_h+otherW_abroad_sub_h+PEVAL_h)/HH_size
	gen A_PE=PEVAL_h/HH_size
	gen A_Hous=(house_h)/HH_size
	gen A_GroW=gw_h/HH_size
	gen A_Debt=(debt_h)/HH_size
	gen A_NetW=nw_h/HH_size

	g nom_sfpc  =nom_sf/HH_size	/*Income from all safe assets*/
	g nom_rspc  =nom_rs/HH_size	/*Income from risky fin. assets*/
	g nom_pepc  =nom_pe/HH_size	/*Income from private equity*/
	g nom_hspc  =nom_hs/HH_size	/*Income from housing*/
	g nom_dbpc  =nom_db/HH_size	/*Interests on debt*/

***
	gen Part_SafeF=(safe_h)>0												/*This is participation in safe fin. assets*/
	gen Part_RiskF=(tot_val_end_h+mfund_h+otherW_abroad_sub_h)>0			/*This is participation in liquid risky assets*/
	gen Part_RiskT=(tot_val_end_h+mfund_h+otherW_abroad_sub_h+PEVAL_h)>0	/*This is participation in all risky assets*/
	gen Part_Publ=(tot_val_end_h+mfund_h)>0
	gen Part_Priv=(PEVAL_h)>0
	gen Part_Hous=(house_h)>0
	gen Part_Debt=(debt_h)>0

	gen Val_SafeF=(safe_h)/gw_h
	gen CVal_SafeF=Val_SafeF if Part_SafeF==1
	gen Val_RiskF=(tot_val_end_h+mfund_h+otherW_abroad_sub_h)/gw_h
	gen CVal_RiskF=Val_RiskF if Part_RiskF==1
	gen Val_RiskT=(tot_val_end_h+mfund_h+otherW_abroad_sub_h+PEVAL_h)/gw_h
	gen CVal_RiskT=Val_RiskT if Part_RiskT==1
	gen Val_Publ=(tot_val_end_h+mfund_h)/gw_h
	gen CVal_Publ=Val_Publ if Part_Publ==1
	gen Val_Priv=(PEVAL_h)/gw_h						
	gen CVal_Priv=Val_Priv if Part_Priv==1
	gen Val_Hous=(house_h)/gw_h
	gen CVal_Hous=Val_Hous if Part_Hous==1

	gen Val_DebtM=(debt_oth_h)/gw_h
	gen Val_DebtC=(debt_cons_h)/gw_h
	gen Val_DebtS=(debt_stud_h)/gw_h

***Some Winsorization
	foreach x in M C S { 
	forvalues j=2004(1)2015	{
		qui su Val_Debt`x' if year==`j',d
		replace Val_Debt`x'=r(p99) if Val_Debt`x'>r(p99) & Val_Debt`x'<. & year==`j'
		}
	}

	lab var A_FinW "Financial wealth"
	lab var A_Safe "Safe assets"
	lab var A_RiskF "Risky fin. assets"
	lab var A_RiskT "Risky tot. assets"
	lab var A_NonfinW "Non-financial wealth"
	lab var A_PE   "Private equity"
	lab var A_Hous "Housing"
	lab var A_GroW "Gross wealth"
	lab var A_Debt "Debt"
	lab var A_NetW "Net worth"

	lab var nom_sfpc "Income from safe assets"
	lab var nom_rspc "Income from risky fin. assets"
	lab var nom_pepc "Income from priv. bus."
	lab var nom_hspc "Housing yield"
	lab var nom_dbpc "Interest payments on debt"

	lab var Part_SafeF "Fraction with safe fin. assets" 
	lab var Val_SafeF  "Safe fin. asset share (out of GW)"
	lab var CVal_SafeF "Cond. safe fin. asset share"
	lab var Part_RiskF "Fraction with risky fin. assets" 
	lab var Val_RiskF  "Risky fin. asset share (out of GW)"
	lab var CVal_RiskF "Cond. risky fin. asset share"
	lab var Part_RiskT "Fraction with any risky assets" 
	lab var Val_RiskT  "Any risky asset share (out of GW)"
	lab var CVal_RiskT "Cond. any risky asset share"
	lab var Part_Publ "Fraction with public equity"
	lab var Val_Publ "Public equity share (out of GW)"
	lab var CVal_Publ "Cond. public equity share"
	lab var Part_Priv "Fraction with private equity"
	lab var Val_Priv "Private equity share (out of GW)"
	lab var CVal_Priv "Cond. private equity share"
	lab var Part_Hous "Fraction with housing"
	lab var Val_Hous "Housing/Gross wealth ratio"
	lab var CVal_Hous  "Cond. housing/Gross wealth ratio"
	lab var Part_Debt "Fraction with debt"
	lab var Val_DebtM "Leverage, LT debt"
	lab var Val_DebtC "Leverage, Cons. debt"
	lab var Val_DebtS "Leverage, Stud. debt"


*******************************************TABLE 2 *************************************************************************************************
	eststo clear
	eststo: estpost tabstat  ///
	age male Dmarital3 size LTHS HS CE educ_year econdegree ///
	, statistics(mean sd p10 p50 p90 p99 N) columns(statistics) 
	local sum_statistics "mean(label(Mean) fmt(2)) sd(label(Std. dev) fmt(2)) p10(label(P10) fmt(2)) p50(label(Median) fmt(2)) p90(label(P90) fmt(2)) p99(label(P99) fmt(2))"
	esttab using $dir_tables/TABLE_2A.tex  , cells("`sum_statistics'") label replace title(Demographics) nomtitles nonumbers obslast

	eststo clear
	eststo: estpost tabstat  ///
	A_FinW-A_NetW ///
	, statistics(mean sd p10 p50 p90 p99 N) columns(statistics) 
	local sum_statistics "mean(label(Mean) fmt(%9.0fc)) sd(label(Std. dev) fmt(%9.0fc)) p10(label(P10) fmt(%9.0fc)) p50(label(Median) fmt(%9.0fc)) p90(label(P90) fmt(%9.0fc)) p99(label(P99) fmt(%9.0fc))"
	esttab using $dir_tables/TABLE_2B.tex  , cells("`sum_statistics'") label replace title(Stocks) nomtitles nonumbers obslast

	eststo clear
	eststo: estpost tabstat  ///
	nom_sfpc nom_rspc nom_pepc nom_hspc nom_dbpc ///
	, statistics(mean sd p10 p50 p90 p99 N) columns(statistics) 
	local sum_statistics "mean(label(Mean) fmt(%9.0fc)) sd(label(Std. dev) fmt(%9.0fc)) p10(label(P10) fmt(%9.0fc)) p50(label(Median) fmt(%9.0fc)) p90(label(P90) fmt(%9.0fc)) p99(label(P99) fmt(%9.0fc))"
	esttab using $dir_tables/TABLE_2C.tex  , cells("`sum_statistics'") label replace title(Stocks) nomtitles nonumbers obslast

	eststo clear
	eststo: estpost tabstat  ///
	Part_SafeF-Val_DebtS ///
	, statistics(mean sd p10 p50 p90 p99 N) columns(statistics) 
	local sum_statistics "mean(label(Mean) fmt(2)) sd(label(Std. dev) fmt(2)) p10(label(P10) fmt(2)) p50(label(Median) fmt(2)) p90(label(P90) fmt(2)) p99(label(P99) fmt(2))"
	esttab using $dir_tables/TABLE_2D.tex  , cells("`sum_statistics'") label replace title(Stocks) nomtitles nonumbers obslast
******************************************************************************************************************************************************
! $fpost/fpost "$dir_tables/TABLE_2A.tex"
! $fpost/fpost "$dir_tables/TABLE_2B.tex"
! $fpost/fpost "$dir_tables/TABLE_2C.tex"
! $fpost/fpost "$dir_tables/TABLE_2D.tex"

	drop A_FinW-Val_DebtS

*********************RETURNS STATISTICS *************
******************************************************************************
lab var t_rr_fw  "Financial wealth"
lab var t_rr_sf  "Safe fin. assets"
lab var t_rr_dep "Deposits"
lab var t_rr_bo  "Other safe assets"
lab var t_rr_rs  "Risky fin. assets"
lab var t_rr_ls  "Listed shares"
lab var t_rr_mf  "Mutual funds"
lab var t_rr_ds  "Direct stockh."
lab var t_rr_fx  "Foreign assets"
lab var t_rr_nfw "Non-financial wealth"
lab var t_rr_hs  "Housing"
lab var t_rr_pe  "Private equity"
lab var t_rr_oc  "Outst. claims"
lab var t_rr_gw  "Gross wealth"
lab var t_rr_nw  "Net worth (before tax)"
lab var t_rr_atnw "Net worth (after tax)"
lab var t_rr_db  "Debt"
lab var t_rr_dbm "Long-term debt"
lab var t_rr_dbc "Consumer debt"
lab var t_rr_dbs "Student debt"

g t_rr_nw_u=t_rr_nw
g t_rr_atnw_u=t_rr_atnw
g w_nw_u=1			/*to create equally weighted returns*/
g w_atnw_u=1		/*to create equally weighted returns*/
lab var t_rr_nw_u   "Net worth (before tax, unweighted)"
lab var t_rr_atnw_u "Net worth (after tax, unweighted)"

****Selected returns
*********************TABLE 3 *******************************************************************************************************
qui: su t_rr_nw [w=w_nw],d
matrix output = (r(mean),r(sd),r(skewness),r(kurtosis),r(p10),r(p50),r(p90))
foreach x in atnw nw_u atnw_u fw sf rs nfw hs pe db dbm dbc dbs {
              qui: su t_rr_`x' [w=w_`x'],d
              matrix output = output\(r(mean),r(sd),r(skewness),r(kurtosis),r(p10),r(p50),r(p90))
                             }
matrix rownames output =  t_rr_nw t_rr_atnw  t_rr_nw_u t_rr_atnw_u t_rr_fw t_rr_sf t_rr_rs t_rr_nfw t_rr_hs t_rr_pe ///
                          t_rr_db t_rr_dbm t_rr_dbc t_rr_dbs 
matrix colnames output = Mean SD Skewness Kurtosis P10 Median P90 
outtable using "$dir_tables/TABLE_3", mat(output) replace nobox center label f(%9.4f %9.4f %9.2f %9.2f %9.4f %9.4f %9.4f)
! $fpost/fpost "$dir_tables/TABLE_3.tex"

drop t_rr_nw_u-w_atnw_u

************************************************************************************************************************************

************************FIGURE 1*********************************************************************************************
preserve
	gen xxx1=ceil(risky_share*100)
	gcollapse (sd) t_rr_fw* ,by(xxx1) 
	drop if xxx1==.
	sort xxx1
	lab var xxx1 "Share invested in risky financial assets"
	scatter t_rr_fw xxx1,c(l l) s(i i) clp(solid dash) graphregion(color(white)) ///
		ytitle("St.dev. return fin. wealth") ylabel(0(0.02)0.16)
	graph export "$dir_figures/FIGURE_1.pdf", as(pdf) replace
restore
! $fpost/fpost "$dir_figures/FIGURE_1.pdf"

************************FIGURE OA.7*********************************************************************************************
preserve
	gen xxx1=ceil(risky_share*100)
	gcollapse (sd) t_rr_fw ,by(xxx1 year) 
	lab var xxx1 "Share invested in risky financial assets"
	forvalues j=2005(1)2015	{
	scatter t_rr_fw xxx1 if year==`j',c(l l) s(i i) clp(solid dash) graphregion(color(white)) ///
		ytitle(" ") xtitle(" ") title("`j'") saving(a`j',replace) xtitle("") nodraw
		}
	graph combine 	a2005.gph a2006.gph a2007.gph a2008.gph a2009.gph a2010.gph ///
			a2011.gph a2012.gph a2013.gph a2014.gph a2015.gph ,iscale(.6) graphr(c(white)) xcommon nocopies
	graph export "$dir_figures/FIGURE_OA7.pdf", as(pdf) replace
restore
! $fpost/fpost "$dir_figures/FIGURE_OA7.pdf"
*******************************************************************************************************************************

**************************SCALE DEPENDENCE FW and components ****************************************************************
preserve
    gen rr_os      = (nom_bo+nom_oc)/(den_bo +den_oc)-inflation				/*Other safe assets, non deposits*/
	trim rr_os 0.5 99.5

	gcollapse 	(mean) a=t_rr_fw t_rr_sf t_rr_dep t_rr_os t_rr_ls t_rr_ds t_rr_mf t_rr_fx t_rr_rs t_rr_oc  ///
			(median) m=t_rr_fw (sd) s=t_rr_fw,by(q100fw) 
	lab var a "Average return"
	lab var m "Median return"
	lab var q100 "Percentile of the financial wealth distribution"
	lab var s "SD, return to financial wealth"
*******FIGURE OA.8
	scatter s q,c(l) s(oh) graphr(c(white))
	graph export "$dir_figures/FIGURE_OA8.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_OA8.pdf"
************
	lab var t_rr_sf "Return on safe assets"
	lab var t_rr_oc "Return on outst. claims"
	lab var t_rr_dep "Return on deposits"
	lab var t_rr_os "Return on other safe ass."
	lab var t_rr_fx "Return on foreign ass."
	lab var t_rr_ls "Return on listed shares"
	lab var t_rr_mf "Return on mutual funds"
	lab var t_rr_ds "Return on direct stockh."
	lab var t_rr_rs "Return on risky fin. assets"

******************** FIGURE 2, PANEL A **********************************************************************************************
	scatter a m q100,c(l l) clp(solid dash) s(i i) ylabel(-0.01(.01).02) graphr(c(white)) legend(reg(lc(white)) size(small) cols(2))
	graph export "$dir_figures/FIGURE_2A.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_2A.pdf"
*************************************************************************************************************************************

******************* FIGURE 3 ********************************************************************************************************
	lowess t_rr_sf q100, s(x) title("Return on safe assets") saving(rsf,replace) note(" ") graphregion(color(white)) ytitle(" ") ylabel(-0.01(0.005)0.01)   nodraw
	lowess t_rr_rs q100, s(x) title("Return on risky assets") saving(rra,replace) note(" ") graphregion(color(white)) ytitle(" ") nodraw
	graph combine rsf.gph rra.gph, graphregion(color(white)) nocopies
	graph export "$dir_figures/FIGURE_3.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_3.pdf"************************************************************************************************************************************
	
******************* FIGURE OA.12****************************************************************************************************
	lowess t_rr_fx q100,c( . l) s(x) title("Return on foreign ass.") saving(rfx,replace) note(" ") graphregion(color(white)) ytitle(" ")  nodraw
	lowess t_rr_ds q100,c( . l) s(x) title("Return on direct stockh.") saving(rds,replace) note(" ") graphregion(color(white)) ytitle(" ") nodraw
	lowess t_rr_mf q100,c(. l) s(x) title("Return on mutual funds") saving(rmf,replace) note(" ") graphregion(color(white)) ytitle(" ") nodraw
	graph combine rfx.gph rmf.gph rds.gph , graphregion(color(white)) altshrink nocopies
	graph export "$dir_figures/FIGURE_OA12A.pdf", as(pdf) replace

	lowess t_rr_dep q100,c( . l) s(x) title("Return on deposits") saving(rdp,replace) note(" ") graphregion(color(white)) ytitle(" ")
 	lowess t_rr_os q100,c( . l) s(x) title("Return on other safe ass.") saving(rbo,replace) note(" ") graphregion(color(white)) ytitle(" ")
	graph combine rdp.gph rbo.gph , graphregion(color(white)) 
	graph export "$dir_figures/FIGURE_OA12B.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_OA12A.pdf"
	! $fpost/fpost "$dir_figures/FIGURE_OA12B.pdf"
************************************************************************************************************************************
restore

********COMMON RETURN ON SAFE ASSETS STUFF (_kD=common return on deposits; _kDB=common return on deposits & bonds)
preserve
	gcollapse (mean) a=t_rr_fw ad=t_rr_fw_kD adb=t_rr_fw_kDB (median) m=t_rr_fw md=t_rr_fw_kD mdb=t_rr_fw_kDB ///
	(sd) s=t_rr_fw sd=t_rr_fw_kD sdb=t_rr_fw_kDB, by(q100fw) 

	lab var a  "Baseline"
	lab var ad  "Common return on dep."
	lab var adb  "Common return on dep. & bonds"
	lab var q100 "Percentile of the financial wealth distribution"

******************** FIGURE 2, PANEL B **********************************************************************************************
	scatter ad adb q100,c(l l l l) s(i i) clp(solid dash) legend(reg(lc(white)) size(small)) graphr(c(white))
	graph export "$dir_figures/FIGURE_2B.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_2B.pdf"
*************************************************************************************************************************************

******************** FIGURE OA.9, PANEL A **********************************************************************************************
	lab var s  "Baseline"
	lab var sd  "Common return on dep."
	lab var sdb  "Common return on dep. & bonds"
	scatter s sd sdb q100,c(l l l l) s(oh i x) clp(solid dash solid) legend(reg(lc(white)) size(small) cols(3)) graphr(c(white)) 
	graph export "$dir_figures/FIGURE_OA9A.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_OA9A.pdf"
*************************************************************************************************************************************
restore

preserve
	gen xxx1=ceil(risky_share*100)
	gcollapse (sd) t_rr_fw* ,by(xxx1) 
	drop if xxx1==.
	sort xxx1
	lab var xxx1 "Share invested in risky financial assets"
	scatter t_rr_fw xxx1,c(l l) s(i i) clp(solid dash) graphregion(color(white)) ///
		ytitle("St.dev. return fin. wealth") ylabel(0(0.02)0.16)
	graph export "$dir_figures/merton_samuelson_basic.pdf", as(pdf) replace
	lab var t_rr_fw "Baseline"
	lab var t_rr_fw_kDB "Common return on dep. & bonds"
	lab var t_rr_fw_kD  "Common return on dep."
******************** FIGURE OA.9, PANEL B **********************************************************************************************
	scatter t_rr_fw t_rr_fw_kD t_rr_fw_kDB xxx1,c(l l l) s(oh i x) clp(solid dash solid) graphregion(color(white)) ///
		ylabel(0(0.02)0.16) legend(reg(lc(white)) size(small) cols(3)) 
	graph export "$dir_figures/FIGURE_OA9B.pdf", as(pdf) replace
*************************************************************************************************************************************
restore
! $fpost/fpost "$dir_figures/FIGURE_OA9B.pdf"


******************************************************
******************************************************
preserve
	keep lnr year todropNW* t_rr_fw q100Lfw 
	egen allyears=count(lnr!=.),by(lnr)
	keep if allyears==11

	replace t_rr_fw=. if year==2004
	egen mr=mean(t_rr_fw),by(lnr)
	egen sr=sd(t_rr_fw),by(lnr)
	keep if year==2005
	reg m s i.q100
	g xxx=0
	forvalues i=1(1)100	{
		replace xxx=_b[`i'.q100] if q100==`i'
	}

	gcollapse xxx,by(q100)
	lab var xxx "Volatility-adjusted average return to financial wealth"
	lab var q "Percentile of the financial wealth distribution, 2004"
****FIGURE 4 **************************************************
	scatter xxx q,s(o) graphr(c(white))
	graph export "$dir_figures/FIGURE_4.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_4.pdf"
******************************************************
restore


******************************************************
*******************************SCALE DEP NW***************
******************************************************
preserve
	gcollapse (mean) a=t_rr_nw t_rr_atnw t_rr_gw (median) m=t_rr_nw ,by(q100nw) 
	lab var q100 "Percentile of the net worth distribution"
	lab var a "Before-tax return"
	lab var t_rr_atnw "After-tax return"

***************FIGURE 7, TOP LEFT PANEL ******************************************************************************
	scatter a t_rr_atnw q100,c(l l) clp(solid dash) s(i i) graphr(c(white)) legend(reg(lc(white)) size(small) cols(2))
	graph export "$dir_figures/FIGURE_7A.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_7A.pdf"**********************************************************************************************************************

	lab var a "Avg. ret. to net worth"
	lab var m "Med. ret. to net worth"
	lab var t_rr_gw "Avg. ret. to gross wealth"

***************FIGURE 5, PANEL A *************************************************************************************
	scatter a m q100,c(l l) clp(solid dash) s(i i) graphr(c(white)) legend(reg(lc(white)) size(small) cols(2))
	graph export "$dir_figures/FIGURE_5A.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_5A.pdf"**********************************************************************************************************************

***************FIGURE 5, PANEL B *************************************************************************************
	scatter a  t_rr_gw q100 if q100>20, c(l l l) s(i  x)  clp(solid dash solid)  graphr(c(white)) ///
	saving(a,replace) title("Top 80%",size(small)) legend(reg(lc(white)) size(small) cols(1)) nodraw
	scatter a  t_rr_gw q100 if q100<=20, c(l l l) s(i  x)  clp(solid dash solid) graphr(c(white)) ///
	saving(b,replace) title("Bottom 20%",size(small)) legend(reg(lc(white)) size(small) cols(1)) nodraw
	graph combine b.gph a.gph,graphr(c(white)) nocopies
	graph export "$dir_figures/FIGURE_5B.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_5B.pdf"
**********************************************************************************************************************
restore

**********************************************************************************************************************
preserve
	g a1=fw_h/(gw_h)
	g a2=PEVAL_h/(gw_h)
	g a3=house_h/(gw_h)
	g a4=debt_h/(gw_h)

	forvalues j=2004(1)2015	{
		qui su a4 if year==`j',d
		replace a4=r(p99) if a4>r(p99) & a4<. & year==`j'
		}

	g a5=a2+a3
	gen PEGUY=t_rr_pe!=.

	gcollapse a1 a2 a3 a4 a5 t_rr_nfw t_rr_fw t_rr_pe t_rr_hs t_rr_db PEGUY, by(q100nw)
	lab var PEGUY "Entrepr. rate"
	lab var a1 "Fin.w./gross wealth"
	lab var a2 "Priv.eq./gross wealth"
	lab var a3 "Hous.w./gross wealth"
	lab var a4 "Liab./gross wealth (rx axis)"
	lab var a5 "Non-fin.w./gross wealth"
	lab var q100 "Percentile of the net worth distribution"
	lab var t_rr_nfw "Return to non-fin.w."
	lab var t_rr_fw "Return to fin.w."
	lab var t_rr_db "Cost of debt (rx axis)"
	lab var t_rr_pe "Return to priv.eq. (rx axis)"
	lab var t_rr_hs "Return to hous.w."
	lab var q100 "Percentile of the net worth distribution"

***************FIGURE 6 **********************************************************************************************
	tw (scatter a1 PEGUY q100, yaxis(1) c(l l l) s(i i x) clp(solid dash solid) legend(reg(lc(white)) size(small) cols(2)) graphr(c(white)) ///
	saving(a1,replace)) (scatter a4 q100, yaxis(2) c(l) clp(dash) s(sh))	
	scatter t_rr_fw t_rr_nfw t_rr_db q100, yaxis(1) c(l l l) s(i i sh) clp(solid dash dash) legend(col(2) reg(lc(white)) size(small)) ///
	saving(a2,replace)  graphr(c(white)) 
	graph combine a1.gph a2.gph, graphr(c(white)) iscale(.6) nocopies
	graph export "$dir_figures/FIGURE_6.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_6.pdf"
**********************************************************************************************************************
	drop a1-a5
restore
**********************************************************************************************************************

************************************************************************************************************************************************************
preserve
	gcollapse (mean) a=t_rr_nw ad=t_rr_nw_kD adb=t_rr_nw_kDB (median) m=t_rr_nw md=t_rr_nw_kD mdb=t_rr_nw_kDB, by(q100nw) 

	lab var a  "Baseline"
	lab var ad  "Common return on dep."
	lab var adb  "Common return on dep. & bonds"
	lab var q100 "Percentile of the net worth distribution"

**********FIGURE 7, TOP RIGHT PANEL************************************************************************************************************************

	scatter a adb q100,c(l l l l) s(i i) clp(solid dash) title("Return on net worth") legend(reg(lc(white)) size(small) cols(2)) ///
	graphregion(color(white)) saving(c,replace)
	graph export "$dir_figures/FIGURE_7B.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_7B.pdf"
************************************************************************************************************************************************************
restore


************************************************************************************************************************************************************
************************************************************************************************************************************************************
preserve 
	gcollapse (sd) sd=t_rr_nw [w=w_nw],by(year) 
	lab var sd "St.dev. return to net worth"
	lab var year "Year"
***********FIGURE OA.5
	scatter sd year, c(l) s(+) graphr(c(white)) xtitle("") xlabel(2005(2)2015) clp(solid dash) legend(cols(1)) 
	graph export "$dir_figures/FIGURE_OA5.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_OA5.pdf"
restore
************************************************************************************************************************************************************

**************************************************************************************
preserve
	gcollapse (sd) t_rr_sf [w=w_sf],by(year) 
	sort year
	save temp1,replace
restore
preserve
	gcollapse (sd) t_rr_pe [w=w_pe],by(year) 
	sort year
	save temp2,replace
restore
preserve
	gcollapse (sd) t_rr_ls [w=w_ls],by(year) 
	sort year
	merge year using temp1
	drop _merge
	sort year
	merge year using temp2
	drop _merge
	drop if year==2004
	
	gen rel_ls=t_rr_ls/t_rr_sf
	gen rel_pe=t_rr_pe/t_rr_sf
	lab var rel_ls "SD(listed shares)/SD(safe assets)"
	lab var rel_pe "SD(private equity)/SD(safe assets)"
	lab var year "Year"
*************FIGURE OA.6
	scatter rel_ls rel_pe year,c(l l) clp(solid dash) s(i i) graphr(c(white)) xlabel(2005(2)2015) legend(reg(lc(white)) size(small) cols(2)) 
	graph export "$dir_figures/FIGURE_OA6.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_OA6.pdf"
restore
*************************************************************************************

*************FIGURE OA.10
preserve
	gcollapse t_rr_fw,by(q100fw year) 
	forvalues j=2005(1)2015	{
		lowess t_rr_fw q100 if year==`j', s(+) saving(corr`j',replace) title("`j'") ytitle(" ") xtitle(" ") graphr(c(white)) note(" ") nodraw
		}
		graph combine 	corr2005.gph /// 	
				corr2006.gph /// 	
				corr2007.gph /// 	
				corr2008.gph /// 	
				corr2009.gph /// 	
				corr2010.gph /// 	
				corr2011.gph /// 	
				corr2012.gph /// 	
				corr2013.gph /// 	
				corr2014.gph /// 	
				corr2015.gph ,graphr(c(white)) iscale(.4) nocopies
		graph export "$dir_figures/FIGURE_OA10.pdf", as(pdf) replace 
restore
	! $fpost/fpost "$dir_figures/FIGURE_OA10.pdf"
*************************************************************************************


*************FIGURES 0A.13 AND OA.14
*************************************************************************************
preserve
	gen dec=5.5 if q100fw>=1 & q100fw<=9
	replace dec=15.5 if q100fw>=10 & q100fw<=19
	replace dec=25.5 if q100fw>=20 & q100fw<=29
	replace dec=q100fw if q100fw>=30
	gcollapse t_rr_ds t_rr_sf ,by(dec year) 
		forvalues j=2005(1)2015	{
			lowess t_rr_sf dec if year==`j', s(+) saving(corr`j',replace) title("`j'") ytitle(" ") xtitle(" ") graphr(c(white)) note(" ") nodraw
		}
		graph combine corr2005.gph /// 	
			 corr2006.gph /// 	
			 corr2007.gph /// 	
			 corr2008.gph /// 	
			 corr2009.gph /// 	
			 corr2010.gph /// 	
			 corr2011.gph /// 	
			 corr2012.gph /// 	
			 corr2013.gph /// 	
			 corr2014.gph /// 	
			 corr2015.gph ,graphr(c(white))  iscale(.4) nocopies
			graph export "$dir_figures/FIGURE_OA13.pdf", as(pdf) replace
		forvalues j=2005(1)2015	{
			lowess t_rr_ds dec if year==`j', s(+) saving(corr`j',replace) title("`j'") ytitle(" ") xtitle(" ") graphr(c(white)) note(" ") nodraw
		}
		graph combine corr2005.gph /// 	
			 corr2006.gph /// 	
			 corr2007.gph /// 	
			 corr2008.gph /// 	
			 corr2009.gph /// 	
			 corr2010.gph /// 	
			 corr2011.gph /// 	
			 corr2012.gph /// 	
			 corr2013.gph /// 	
			 corr2014.gph /// 	
			 corr2015.gph ,graphr(c(white))  iscale(.4) nocopies
			graph export "$dir_figures/FIGURE_OA14.pdf", as(pdf) replace
restore
	! $fpost/fpost "$dir_figures/FIGURE_OA13.pdf"
	! $fpost/fpost "$dir_figures/FIGURE_OA14.pdf"
*************************************************************************************


*************FIGURES 0A.15
*************************************************************************************
preserve
	gcollapse t_rr_nw ,by(q100nw year) 
		forvalues j=2005(1)2015	{
			scatter t_rr_nw q100 if year==`j', c(l) s(+) saving(corr`j',replace) title("`j'") ytitle(" ") xtitle(" ") graphr(c(white)) nodraw
			}
	graph combine 	corr2005.gph /// 	
			corr2006.gph /// 	
			corr2007.gph /// 	
			corr2008.gph /// 	
			corr2009.gph /// 	
			corr2010.gph /// 	
			corr2011.gph /// 	
			corr2012.gph /// 	
			corr2013.gph /// 	
			corr2014.gph /// 	
			corr2015.gph ,graphr(c(white)) iscale(.4) nocopies
	graph export "$dir_figures/FIGURE_OA15.pdf", as(pdf) replace
restore
	! $fpost/fpost "$dir_figures/FIGURE_OA15.pdf"

*************************************************************************************

*************FIGURES 0A.16, PANEL A
******************************************************************************************************************************
preserve
	gcollapse t_rr_sf t_rr_rs t_rr_hs t_rr_pe,by(q100nw)
	label var q100nw "Percentile net worth distribution"
	label var t_rr_rs "Return to risky fin. assets"
	label var t_rr_sf "Return to safe fin.ass."
	label var t_rr_pe "Return to private eq."
	label var t_rr_hs "Return to housing" 
	lowess t_rr_sf q100,saving(a1,replace) s(x) bw(.1) note (" ") graphr(c(white)) title(" ")
	lowess t_rr_rs q100,saving(a2,replace) s(x) note (" ") graphr(c(white)) title(" ")
	lowess t_rr_pe q100,saving(a3,replace) s(x) note (" ") graphr(c(white)) title(" ")
	lowess t_rr_hs q100,saving(a4,replace) s(x) note (" ") graphr(c(white)) title(" ")
	graph combine a1.gph a2.gph a3.gph a4.gph, graphr(c(white)) iscale(.6)
restore
graph export "$dir_figures/FIGURE_OA16A.pdf", as(pdf) replace
! $fpost/fpost "$dir_figures/FIGURE_OA16A.pdf"
******************************************************************************************************************************

*************FIGURES 0A.16, PANEL B
******************************************************************************************************************************
preserve
	gen y=inc_earned_h
	replace y=. if y<=0
	keep if y>30000 & y!=.
	gcollapse t_rr_dbs,by(q100nw)
	ren t_rr_dbs t_rr_dbs_rich
	sort q100
	save temp,replace
restore
preserve
	gcollapse t_rr_dbs,by(q100nw)
	sort q100
	merge q100 using temp
	tab _merge
	label var t_rr_dbs "Cost of student debt"
	label var t_rr_dbs_rich "Cost of student debt, excluding low-income"
	label var q100 "Percentile net worth distribution"
	scatter t_rr_dbs t_rr_dbs_rich q100nw,s(oh x) graphr(c(white)) legend(reg(lc(white)) size(small)) saving(a2,replace) nodraw
restore


preserve
	keep if house_h>0
	gcollapse t_rr_dbm,by(q100nw)
	ren t_rr_dbm t_rr_dbm_hown
	sort q100
	save temp,replace
restore
preserve
	gcollapse t_rr_dbc,by(q100nw)
	sort q100
	merge q100 using temp
	tab _merge
	label var t_rr_dbc "Cost of consumer debt"
	label var t_rr_dbm_hown "Cost of long-term debt (homeowners)"
	label var q100 "Percentile net worth distribution"
	scatter t_rr_dbc t_rr_dbm_hown q100nw,s(oh x) graphr(c(white)) legend(reg(lc(white)) size(small)) saving(a1,replace) nodraw
restore

graph combine a1.gph a2.gph , iscale(.6) graphr(c(white)) nocopies
graph export "$dir_figures/FIGURE_OA16B.pdf", as(pdf) replace
! $fpost/fpost "$dir_figures/FIGURE_OA16B.pdf"

******************************************************************************************************************************

*************FIGURES 0A.17, PANEL B
******************************************************************************************************************************
preserve
	g gw_ind=log(gw_h/HH_size)
	g labinc_ind=log(inc_earned_h/HH_size)
	drop if q100nw==.
	gcollapse gw_ind labinc_ind,by(q100nw) 

	lab var g "Log(gross wealth)"
	lab var l "Log(labor income)"
	lab var q100 "Percentile net worth distribution"

	tw 	scatter gw labinc q100,graphr(c(white)) ylabel(7(1)16) xlabel(0(20)100) s(i i) clp(solid dash) c(l l) ///
		legend(col(2) size(small) reg(lc(white))) 
	graph export "$dir_figures/FIGURE_OA17B.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_OA17B.pdf"
restore
******************************************************************************************************************************

*************FIGURES 0A.18
*************************************************************************************
preserve
	gcollapse t_rr_pe ,by(q100nw year) 
		forvalues j=2005(1)2015	{
			lowess t_rr_pe q100 if year==`j', s(+) saving(corr`j',replace) title("`j'") ytitle(" ") ///
			xtitle(" ") note(" ")graphr(c(white)) nodraw
			}
	graph combine 	corr2005.gph /// 	
			corr2006.gph /// 	
			corr2007.gph /// 	
			corr2008.gph /// 	
			corr2009.gph /// 	
			corr2010.gph /// 	
			corr2011.gph /// 	
			corr2012.gph /// 	
			corr2013.gph /// 	
			corr2014.gph /// 	
			corr2015.gph ,graphr(c(white)) iscale(.4) nocopies
	graph export "$dir_figures/FIGURE_OA18.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_OA18.pdf"
restore
*************************************************************************************


*********************TABLE 9 ************************************************************************************************
preserve
	replace t_rr_nw=t_rr_nw*100	
	replace t_rr_atnw=t_rr_atnw*100
	g loglnw_ind=log(lnw_ind)
	xtset lnr year
	g Dt_rr_nw=D.t_rr_nw
	g Dt_rr_atnw=D.t_rr_atnw

	g Dloglnw_ind=D.loglnw_ind
	g D2loglnw_ind=L.Dloglnw_ind
	g Dq100Lnw=D.q100Lnw
	g D2q100Lnw=L.Dq100Lnw

	eststo clear
	eststo: areg t_rr_nw q100Lnw i.year,a(lnr) cluster(hhid)
	eststo: ivregress 2sls Dt_rr_nw (Dq100Lnw=D2q100Lnw) i.year,cluster(hhid)	
	esttab using "$dir_tables/TABLE_9A.tex",nostar keep( q100Lnw  Dq100Lnw) ///
		se(4) b(4) ar2 nogaps replace

	eststo clear
	eststo: areg t_rr_atnw q100Lnw i.year,a(lnr) cluster(hhid)
	eststo: ivregress 2sls Dt_rr_atnw (Dq100Lnw=D2q100Lnw) i.year,cluster(hhid)	
	esttab using "$dir_tables/TABLE_9B.tex",nostar keep(q100Lnw Dq100Lnw) ///
		se(4) b(4) ar2 nogaps replace

restore
	! $fpost/fpost "$dir_tables/TABLE_9A.tex"
	! $fpost/fpost "$dir_tables/TABLE_9B.tex"
******************************************************************************************************************************

*******************BCS PE MEASURE****************************************************************************************************
u t_rr_nw* t_rr_pe* q100nw* todropNW* year using $pre_reg, clear
drop if year==2004

foreach x in DRE	{
	preserve
	drop if todropNW_`x'==1
	gcollapse t_rr_pe_`x' t_rr_nw_`x',by(q100nw_TAX)
	ren q100nw_TAX q100nw
	save temp_`x',replace
	restore
	}

drop if todropNW_BCS==1
gcollapse t_rr_pe_BCS* t_rr_nw_BCS*,by(q100nw_TAX)
ren q100nw_TAX q100nw
sort q100nw
merge q100nw using temp_DRE
drop _merge

foreach x in nw pe	{
	lab var t_rr_`x'_DRE "Strict Alst.-Kopczuk definition" 
	lab var t_rr_`x'_BCS "Alt.def. ret. PE" 
	}
lab var q100 "Percentile of the net worth distribution"

foreach x in nw pe	{
	lab var t_rr_`x'_DRE "Baseline definition" 
	}
************************FIGURE 7, BOTTOM LEFT PANEL 
line t_rr_nw_DRE t_rr_nw_BCS q100,clp(solid dash) s(i i) legend(reg(lc(white)) size(small) cols(2)) graphr(c(white)) 
graph export "$dir_figures/FIGURE_7C.pdf", as(pdf) replace
! $fpost/fpost "$dir_figures/FIGURE_7C.pdf"
***************************************************************************************************************************************************************
clear

***************************DC PENSION WEALTH***************************************************************************
u lnr year todropNW* nw*_h_avg hhid HH_size t_rr_nw* t_rr_fw* fw_h_avg q100nw* q100fw* gw*_h_avg inflation using $pre_reg,clear

sort lnr year
merge lnr year using "/ssb/stamme02/brisk/wk48/returns/temp_DC_wealth.dta"	/*EXTERNAL DATASET CONTAINING DATA ON DEFINED CONTRIBUTION WEALTH AND ITS IMPLIED NOMINAL RETURN (SEE PAPER OA)*/
tab _merge
drop if _merge==2
drop _merge

replace DC_w=0 if DC_w==.
replace implied_return=0 if implied_return==.
egen DC_w_h=sum(DC_w),by(hhid year)

if method==2	{
	cap ren *_DRE *
	cap ren *_DRE_* *_*
	cap ren *_TAX *
	cap ren *_TAX_* *_*
}
else if method==1	{
	cap ren *_BCS *
	cap ren *_BCS_* *_*
}


egen extended_gw_h=rsum(gw_h_avg DC_w_h)

gen t_rr_nw_ext=t_rr_nw*(gw_h_avg/extended_gw_h)+(implied_return-inflation)*(DC_w_h/extended_gw_h)

egen extended_nw_h=rsum(nw_h_avg DC_w_h)

keep if year>=2006 & year<=2014		
drop if todropNW==1


cap drop aux
gen aux = extended_nw_h/HH_size
rank aux year 100
ren q100_aux q100nwext
drop aux

preserve
	gcollapse t_rr_nw,by(q100nw)
	sort q100nw
	save temp,replace
restore

preserve 
	keep lnr year DC_w_h q100nwext extended* t_rr_nw_ext 
	sort lnr year
	save dc_variables_for_FE, replace		/*Save dataset to be used in the FE regressions*/
restore



gcollapse t_rr_nw_ext,by(q100nwext)
ren q100nwext q100nw
sort q100nw
merge q100nw using temp
drop if _merge!=3
drop _merge

lab var t_rr_nw_ext "With DC pension wealth"
lab var t_rr_nw "Baseline"
lab var q100 "Percentile of net worth"
 
*********************FIGURE 7, BOTTOM RIGHT PANEL
scatter t_rr_nw t_rr_nw_ext q100,c(l l) clp(solid dash) s(i i) graphr(c(white)) legend(reg(lc(white)) size(small) cols(2)) 
graph export "$dir_figures/FIGURE_OA.pdf", as(pdf) replace
! $fpost/fpost "$dir_figures/FIGURE_7D.pdf"
clear
**********************************************************



**************Cumulative return figure***********************************
*************************************************************************
u lnr year todropNW* nw*_h_avg t_rr_gw* r_nw* den_nw* debt_h_avg inflation t_rr_nw* t_rr_db q100* HH_size age t_rr_fw* fw_h* inc_earned_h econdegree educ_year using $pre_reg, clear

if method==2	{
	cap ren *_DRE *
	cap ren *_DRE_* *_*
	cap ren *_TAX *
	cap ren *_TAX_* *_*
}
else if method==1	{
	cap ren *_BCS *
	cap ren *_BCS_* *_*
}

preserve
	keep if year==2004
	gen q2004=q100nw
	keep lnr q2004
	sort lnr
	save temp,replace
restore	

cap drop q100*
egen allyears=count(lnr!=.),by(lnr)
keep if allyears==12

cap drop _merge
merge m:1 lnr using  "/path/data/lnr_mlnr_flnr.dta", keep(match master) /*Dataset containing the IDs of parents*/
cap drop _merge

ren lnr LNR

cap drop *merge
ren mlnr lnr
merge m:1 lnr using temp, keep(match master) 
ren q2004 mother_pctl_2004
ren lnr mlnr 

ren flnr lnr
cap drop *merge
merge m:1 lnr using temp, keep(match master) 
ren q2004 father_pctl_2004
ren lnr flnr

ren LNR lnr
egen maxfm=rmax(father_pctl mother_pctl)

g ly=log(inc_earned_h)
egen mly=mean(ly),by(lnr)

gen nw_h_pc=nw_h/HH_size
rank nw_h_pc year 100
gen fw_h_pc=fw_h/HH_size
rank fw_h_pc year 100
ren q100_nw q100nw
ren q100_fw q100fw

gen temp=q100nw if year==2004
egen q2004nw=mean(temp),by(lnr)
drop if year==2004
drop if todropNW==1

gen Rn=log(1+t_rr_nw)
egen temp_cum_Rn=sum(Rn),by(lnr)

keep if year==2015
gen sumretn=exp(temp_cum_Rn)

****regressions for moving to and falling from top 1%**************
g age_in_2004=age-11
g move_to_top1=q100nw==100
g fall=abs(q100nw-q2004)
**************************TABLE OA.4
eststo clear
eststo:reg move_to_top1 sumretn if q2004<100,cluster(lnr)
eststo:reg move_to_top1 sumretn age_in_2004 mly max educ_year econ if q2004<100,cluster(lnr)
eststo:reg fall sumretn if q2004==100 & q100nw<100,cluster(lnr)
eststo:reg fall sumretn age_in_2004 mly max educ_year econ if q2004==100 & q100nw<100,cluster(lnr)
esttab using "$dir_tables/TABLE_OA4.tex",nostar se(4) b(4) nogaps ar2 replace
! $fpost/fpost "$dir_tables/TABLE_OA4.tex"
********************************************************************


	cap drop nw_h_pc
	gen nw_h_pc=nw_h/HH_size
	rank nw_h_pc year 10000

	cap drop bwout* bw* 
	areg sumretn, a(q10000)
	predict bwout,d
	replace bwout=bwout+_b[_cons]
	areg sumretn i.q2004nw,a(q10000)
	predict bw,d
	replace bw=bw+_b[_cons]
	
preserve
	gcollapse bwout bw,by(q10000)
	replace q10000=q10000/100
	lab var bw "Cumulative return, 2005-2015 (contr. for 2004 pctl.)"
	lab var q100 "Net worth fractile, 2015"
****************FIGURE 12*************************************************************************************
	lowess q10000 bw if q10000>=75, s(x) legend(cols(1)) clp(solid) graphr(c(white)) note(" ") ytitle(" ") ///
		ylabel(75 90 95 97.5 99 99.5 99.9, angle(0) labsize(vsmall)) title("") bw(0.1)
	graph export "$dir_figures/FIGURE_12.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_12.pdf"
**************************************************************************************************************
restore






**************************************************************************************************
*INTERGENERATIONAL results -  FINANCIAL WEALTH
***************************************************************************************************

u $keepvars_intergen using $pre_reg , clear

if method==2	{
	cap ren *_DRE *
	cap ren *_DRE_* *_*
	cap ren *_TAX *
	cap ren *_TAX_* *_*
}
else if method==1	{
	cap ren *_BCS *
	cap ren *_BCS_* *_*
}

drop q100*
drop if year==2004
drop if todropNW==1
gen howner=house_h>0
sort lnr
cap drop _merge
merge m:1 lnr using  "/path/data/lnr_mlnr_flnr.dta", keep(match master) /*Dataset containing the IDs of parents*/
gen Cohort=b_year

gen pc_fw_h_avg=fw_h_avg/HH_size
g returns=t_rr_fw

sort year Cohort returns
bys year Cohort (returns): gen nnn=_n
bys year Cohort (returns): gen NNN=_N
gen qq=nnn/NNN
gen q100ret=ceil(qq*100)
drop nnn NNN qq
*wealth
sort year Cohort pc_fw_h_avg
bys year Cohort (pc_fw_h_avg): gen nnn=_n
bys year Cohort (pc_fw_h_avg): gen NNN=_N
gen qq=nnn/NNN
gen q100wealth=ceil(qq*100)
drop nnn NNN qq
preserve 
	cap drop flnr
	rename lnr flnr
	keep flnr q100* returns year howner
	foreach var of varlist q100ret q100wealth returns howner {
		cap ren `var' `var'_fath 
		}
	save temp, replace
restore
**Merge back:
cap drop _merge
merge m:1 flnr year using temp, keep(match master)
cap drop _merge
erase temp.dta


cap drop age
gen age=year-b_year

***************************************************************************************************************************************
*********************TABLE OA.3, COLUMNS 1-3
eststo clear
eststo: qui reg returns returns_fath, cluster(lnr)
eststo: qui reg returns returns_fath i.q100wealth i.q100wealth_fath i.educ_length_max i.educ_type_max age i.year howner*, cluster(lnr)
eststo: qui areg returns returns_fath i.q100wealth i.q100wealth_fath  age i.year howner*, absorb(lnr) vce(cluster lnr)
esttab using "$dir_tables/TABLE_OA3A.tex", label nostar drop(*.year *.q100wealth *.q100wealth_fath) se(4) b(4) nogaps ar2 replace
***************************************************************************************************************************************
! $fpost/fpost "$dir_tables/TABLE_OA3A.tex"

g pe_share=PEVAL_h/gw_h
replace pe_share=0 if pe_share==.

reg q100wealth q100wealth_fath, cluster(lnr)
global slopew=round(_b[q100wealth_fath],.01)
reg q100ret q100ret_fath, cluster(lnr)
global sloper=round(_b[q100ret_fath],.01)

***************************************************************************************************************************************
*********************TABLE 11, COLUMNS 1-3
eststo clear
eststo: qui reg q100ret q100ret_fath, cluster(lnr)
eststo: qui reg q100ret q100ret_fath i.q100wealth i.q100wealth_fath i.educ_length_max i.educ_type_max age i.year howner*, cluster(lnr)
eststo: qui areg q100ret q100ret_fath i.q100wealth i.q100wealth_fath  age i.year howner* , absorb(lnr) vce(cluster lnr)
esttab using "$dir_tables/TABLE_11A.tex", label nostar drop(*.year *.q100wealth *.q100wealth_fath) se(4) b(4) nogaps ar2 replace
***************************************************************************************************************************************
! $fpost/fpost "$dir_tables/TABLE_11A.tex"


lab var q100wealth "Child's wealth avg. percentile"
lab var q100wealth_f "Parent's wealth percentile"
lab var q100ret "Child's wealth return avg. percentile"
lab var q100ret_f "Parent's wealth return percentile"

***************************************************************************************************************************************
*********************FIGURE 11, PANEL B
binscatter q100wealth q100wealth_fath,n(100) ylabel(30(10)80) title("Wealth") saving(a,replace) ///
		ytitle("Child avg. percentile") xtitle("Parent percentile") text(40 40 "Slope=$slopew") ms(oh) nodraw
binscatter q100ret q100ret_fath,n(100) ylabel(30(10)80) title("Return") saving(b,replace) ///
		ytitle("Child avg. percentile") xtitle("Parent percentile") text(48 90 "Slope=$sloper") ms(oh) nodraw
graph combine a.gph b.gph,graphr(c(white)) nocopies
graph export "$dir_figures/FIGURE_11B.pdf", as(pdf) replace
***************************************************************************************************************************************
! $fpost/fpost "$dir_figures/FIGURE_11B.pdf"



**************************************************************************************************
*INTERGENERATIONAL results - NET WORTH
***************************************************************************************************
u $keepvars_intergen using $pre_reg , clear

if method==2	{
	cap ren *_DRE *
	cap ren *_DRE_* *_*
	cap ren *_TAX *
	cap ren *_TAX_* *_*
}
else if method==1	{
	cap ren *_BCS *
	cap ren *_BCS_* *_*
}

g pe_share=PEVAL_h/gw_h
replace pe_share=0 if pe_share==.

drop q100*
drop if year==2004
drop if todropNW==1

gen howner=house_h>0
sort lnr
cap drop _merge
merge m:1 lnr using  "/path/data/lnr_mlnr_flnr.dta", keep(match master) /*Dataset containing the IDs of parents*/
gen Cohort=b_year

gen pc_nw_h_avg=nw_h_avg/HH_size
g ret_bt=t_rr_nw
g ret_at=t_rr_atnw

foreach x in bt at {
	sort year Cohort ret_`x'
	bys year Cohort (ret_`x'): gen nnn=_n
	bys year Cohort (ret_`x'): gen NNN=_N
	gen qq=nnn/NNN
	gen q100ret_`x'=ceil(qq*100)
	drop nnn NNN qq
}


*wealth
sort year Cohort pc_nw_h_avg
bys year Cohort (pc_nw_h_avg): gen nnn=_n
bys year Cohort (pc_nw_h_avg): gen NNN=_N
gen qq=nnn/NNN
gen q100wealth=ceil(qq*100)
drop nnn NNN qq

preserve 
	cap drop flnr
	rename lnr flnr
	keep flnr q100* ret_bt ret_at year howner
	foreach var of varlist q100ret* q100wealth ret_* howner {
		cap ren `var' `var'_fath 
		}
	save temp, replace
restore

**Merge back:
cap drop _merge
merge m:1 flnr year using temp, keep(match master)
cap drop _merge
erase temp.dta


cap drop age
gen age=year-b_year

************************************************************************************************************************************
*****************TABLE OA3, COLUMNS 4-9 *********************************************************************************************
eststo clear
eststo: qui reg ret_bt ret_bt_fath, cluster(lnr)
eststo: qui reg ret_bt ret_bt_fath i.q100wealth i.q100wealth_fath i.educ_length_max i.educ_type_max age i.year howner*, cluster(lnr)
eststo: qui areg ret_bt ret_bt_fath i.q100wealth i.q100wealth_fath  age i.year howner*, absorb(lnr) vce(cluster lnr)
eststo: qui reg ret_at ret_at_fath, cluster(lnr)
eststo: qui reg ret_at ret_at_fath i.q100wealth i.q100wealth_fath i.educ_length_max i.educ_type_max age i.year howner*, cluster(lnr)
eststo: qui areg ret_at ret_at_fath i.q100wealth i.q100wealth_fath  age i.year howner*, absorb(lnr) vce(cluster lnr)
esttab using "$dir_tables/TABLE_OA3B.tex", label nostar drop(*.year *.q100wealth *.q100wealth_fath) se(4) b(4) nogaps ar2 replace
************************************************************************************************************************************
! $fpost/fpost "$dir_tables/TABLE_OA3B.tex"

reg q100wealth q100wealth_fath, cluster(lnr)
global slopew=round(_b[q100wealth_fath],.01)
reg q100ret_bt q100ret_bt_fath, cluster(lnr)
global sloper=round(_b[q100ret_bt_fath],.01)

************************************************************************************************************************************
*****************TABLE 11, COLUMNS 4-9 *********************************************************************************************
eststo clear
eststo: qui reg q100ret_bt q100ret_bt_fath, cluster(lnr)
eststo: qui reg q100ret_bt q100ret_bt_fath i.q100wealth i.q100wealth_fath i.educ_length_max i.educ_type_max age i.year howner*, cluster(lnr)
eststo: qui areg q100ret_bt q100ret_bt_fath i.q100wealth i.q100wealth_fath  age i.year howner* , absorb(lnr) vce(cluster lnr)
eststo: qui reg q100ret_at q100ret_at_fath, cluster(lnr)
eststo: qui reg q100ret_at q100ret_at_fath i.q100wealth i.q100wealth_fath i.educ_length_max i.educ_type_max age i.year howner*, cluster(lnr)
eststo: qui areg q100ret_at q100ret_at_fath i.q100wealth i.q100wealth_fath  age i.year howner*, absorb(lnr) vce(cluster lnr)
esttab using "$dir_tables/TABLE_11B.tex", label nostar drop(*.year *.q100wealth *.q100wealth_fath) se(4) b(4) nogaps ar2 replace
************************************************************************************************************************************
! $fpost/fpost "$dir_tables/TABLE_11B.tex"

lab var q100wealth "Child's wealth avg. percentile"
lab var q100wealth_f "Parent's wealth percentile"
lab var q100ret_bt "Child's wealth return avg. percentile"
lab var q100ret_bt_f "Parent's wealth return percentile"

***********************FIGURE 11, PANEL A ***************************************************************************
binscatter q100wealth q100wealth_fath,n(100) ylabel(40(10)70) title("Wealth") saving(a,replace) ///
		ytitle("Child avg. percentile") xtitle("Parent percentile") text(42 40 "Slope=$slopew") ms(oh) nodraw
binscatter q100ret_bt q100ret_bt_fath,n(100) ylabel(40(10)70) title("Return") saving(b,replace) ///
		ytitle("Child avg. percentile") xtitle("Parent percentile") text(64 90 "Slope=$sloper") ms(oh) nodraw
graph combine a.gph b.gph,graphr(c(white)) nocopies
graph export "$dir_figures/FIGURE_11A.pdf", as(pdf) replace
*********************************************************************************************************************
! $fpost/fpost "$dir_figures/FIGURE_11A.pdf"



********MOBILITY FROM THE BOTTOM 10% IN 2004
u q100* t_rr_nw* t_rr_gw* year todropNW* lnr t_rr_pe* using $pre_reg ,clear

if method==2	{
	cap ren *_DRE *
	cap ren *_DRE_* *_*
	cap ren *_TAX *
	cap ren *_TAX_* *_*
}
else if method==1	{
	cap ren *_BCS *
	cap ren *_BCS_* *_*
}

egen allyears=count(lnr!=.),by(lnr)
keep if allyears==12

gen temp=q100nw if year==2004
egen q2004nw=mean(temp),by(lnr)
drop temp

drop if year==2004
drop if todropNW==1

gen temp=t_rr_pe!=. & year==2005
egen PEGUY2005=sum(temp),by(lnr)

gen Rg=log(1+t_rr_gw)
egen temp_cum_Rg=sum(Rg),by(lnr)

keep if year==2015
gen sumretg=exp(temp_cum_Rg)

g bottom10_2004=q2004nw<=10

g top10_2015=q100nw>=91
tab bottom10_2004 top10_2015 if PEGUY2005==1,row
tab bottom10_2004 top10_2015 if PEGUY2005==0,row

g top5_2015=q100nw>=96
tab bottom10_2004 top5_2015 if PEGUY2005==1,row
tab bottom10_2004 top5_2015 if PEGUY2005==0,row

g top1_2015=q100nw>=100
tab bottom10_2004 top1_2015 if PEGUY2005==1,row
tab bottom10_2004 top1_2015 if PEGUY2005==0,row

g interaction=Rg*PEGUY2005

****************TABLE OA.5
eststo clear
eststo: reg top10_2015 Rg PEGUY2005 interaction if bottom10_2004==1,cluster(lnr)
eststo: reg top5_2015 Rg PEGUY2005 interaction if bottom10_2004==1
eststo: reg top1_2015 Rg PEGUY2005 interaction if bottom10_2004==1
esttab using "$dir_tables/TABLE_OA5.tex", label nostar keep(Rg PEGUY2005 interaction) se(4) b(4) nogaps ar2 replace
! $fpost/fpost "$dir_tables/TABLE_OA5.tex"

preserve
	gcollapse (p10) p10=sumretg (p90) p90=sumretg (p50) p50=sumretg,by(q2004 PEGUY2005)
	g p10_e=p10 if PEGUY2005==1
	g p10_n=p10 if PEGUY2005==0
	g p90_e=p90 if PEGUY2005==1
	g p90_n=p90 if PEGUY2005==0
	g p50_e=p50 if PEGUY2005==1
	g p50_n=p50 if PEGUY2005==0
	lab var q "Net worth percentile, 2004"
****************FIGURE OA.22
	scatter p10_e p50_e p90_e p10_n p50_n p90_n q if q<=10,xlabel(1(1)10)c(l l l l l l) s(i i o i i o) ///
	clp(solid dash dash solid dash dash) legend(off) graphr(c(white)) ///
	text(1.1 8 "10th pctl, non-entr.", size(small)) text(1.25 8 "10th pctl, entr.", size(small)) ///
	text(1.5 5 "50th pctl, non-entr.", size(small)) text(1.66 5 "50th pctl, entr.", size(small)) ///
	text(1.75 2 "90th pctl, non-entr.", size(small)) text(2.4 2 "90th pctl, entr.", size(small))

	graph export "$dir_figures/FIGURE_OA22.pdf", as(pdf) replace
	! $fpost/fpost "$dir_figures/FIGURE_OA22.pdf"
restore
************************



cap log close

cd $dir_logfiles
! $fpost/fpost STATS_FIGURES*_$USER.log

